# Copyright 2015 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# AUTO-GENERATED FROM `$REPO_ROOT/templates/src/python/grpcio/grpc_core_dependencies.py.template`!!!

CORE_SOURCE_FILES = [
    'src/core/ext/filters/census/grpc_context.cc',
    'src/core/ext/filters/client_channel/backend_metric.cc',
    'src/core/ext/filters/client_channel/backup_poller.cc',
    'src/core/ext/filters/client_channel/channel_connectivity.cc',
    'src/core/ext/filters/client_channel/client_channel.cc',
    'src/core/ext/filters/client_channel/client_channel_channelz.cc',
    'src/core/ext/filters/client_channel/client_channel_factory.cc',
    'src/core/ext/filters/client_channel/client_channel_plugin.cc',
    'src/core/ext/filters/client_channel/config_selector.cc',
    'src/core/ext/filters/client_channel/dynamic_filters.cc',
    'src/core/ext/filters/client_channel/global_subchannel_pool.cc',
    'src/core/ext/filters/client_channel/health/health_check_client.cc',
    'src/core/ext/filters/client_channel/http_connect_handshaker.cc',
    'src/core/ext/filters/client_channel/http_proxy.cc',
    'src/core/ext/filters/client_channel/lb_policy.cc',
    'src/core/ext/filters/client_channel/lb_policy/address_filtering.cc',
    'src/core/ext/filters/client_channel/lb_policy/child_policy_handler.cc',
    'src/core/ext/filters/client_channel/lb_policy/grpclb/client_load_reporting_filter.cc',
    'src/core/ext/filters/client_channel/lb_policy/grpclb/grpclb.cc',
    'src/core/ext/filters/client_channel/lb_policy/grpclb/grpclb_balancer_addresses.cc',
    'src/core/ext/filters/client_channel/lb_policy/grpclb/grpclb_channel_secure.cc',
    'src/core/ext/filters/client_channel/lb_policy/grpclb/grpclb_client_stats.cc',
    'src/core/ext/filters/client_channel/lb_policy/grpclb/load_balancer_api.cc',
    'src/core/ext/filters/client_channel/lb_policy/pick_first/pick_first.cc',
    'src/core/ext/filters/client_channel/lb_policy/priority/priority.cc',
    'src/core/ext/filters/client_channel/lb_policy/ring_hash/ring_hash.cc',
    'src/core/ext/filters/client_channel/lb_policy/round_robin/round_robin.cc',
    'src/core/ext/filters/client_channel/lb_policy/weighted_target/weighted_target.cc',
    'src/core/ext/filters/client_channel/lb_policy/xds/cds.cc',
    'src/core/ext/filters/client_channel/lb_policy/xds/xds_cluster_impl.cc',
    'src/core/ext/filters/client_channel/lb_policy/xds/xds_cluster_manager.cc',
    'src/core/ext/filters/client_channel/lb_policy/xds/xds_cluster_resolver.cc',
    'src/core/ext/filters/client_channel/lb_policy_registry.cc',
    'src/core/ext/filters/client_channel/local_subchannel_pool.cc',
    'src/core/ext/filters/client_channel/proxy_mapper_registry.cc',
    'src/core/ext/filters/client_channel/resolver.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/dns_resolver_ares.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/grpc_ares_ev_driver_event_engine.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/grpc_ares_ev_driver_posix.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/grpc_ares_ev_driver_windows.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/grpc_ares_wrapper.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/grpc_ares_wrapper_event_engine.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/grpc_ares_wrapper_posix.cc',
    'src/core/ext/filters/client_channel/resolver/dns/c_ares/grpc_ares_wrapper_windows.cc',
    'src/core/ext/filters/client_channel/resolver/dns/dns_resolver_selection.cc',
    'src/core/ext/filters/client_channel/resolver/dns/native/dns_resolver.cc',
    'src/core/ext/filters/client_channel/resolver/fake/fake_resolver.cc',
    'src/core/ext/filters/client_channel/resolver/google_c2p/google_c2p_resolver.cc',
    'src/core/ext/filters/client_channel/resolver/sockaddr/sockaddr_resolver.cc',
    'src/core/ext/filters/client_channel/resolver/xds/xds_resolver.cc',
    'src/core/ext/filters/client_channel/resolver_registry.cc',
    'src/core/ext/filters/client_channel/resolver_result_parsing.cc',
    'src/core/ext/filters/client_channel/retry_filter.cc',
    'src/core/ext/filters/client_channel/retry_service_config.cc',
    'src/core/ext/filters/client_channel/retry_throttle.cc',
    'src/core/ext/filters/client_channel/server_address.cc',
    'src/core/ext/filters/client_channel/service_config.cc',
    'src/core/ext/filters/client_channel/service_config_channel_arg_filter.cc',
    'src/core/ext/filters/client_channel/service_config_parser.cc',
    'src/core/ext/filters/client_channel/subchannel.cc',
    'src/core/ext/filters/client_channel/subchannel_pool_interface.cc',
    'src/core/ext/filters/client_idle/client_idle_filter.cc',
    'src/core/ext/filters/deadline/deadline_filter.cc',
    'src/core/ext/filters/fault_injection/fault_injection_filter.cc',
    'src/core/ext/filters/fault_injection/service_config_parser.cc',
    'src/core/ext/filters/http/client/http_client_filter.cc',
    'src/core/ext/filters/http/client_authority_filter.cc',
    'src/core/ext/filters/http/http_filters_plugin.cc',
    'src/core/ext/filters/http/message_compress/message_compress_filter.cc',
    'src/core/ext/filters/http/message_compress/message_decompress_filter.cc',
    'src/core/ext/filters/http/server/http_server_filter.cc',
    'src/core/ext/filters/max_age/max_age_filter.cc',
    'src/core/ext/filters/message_size/message_size_filter.cc',
    'src/core/ext/filters/workarounds/workaround_cronet_compression_filter.cc',
    'src/core/ext/filters/workarounds/workaround_utils.cc',
    'src/core/ext/transport/chttp2/alpn/alpn.cc',
    'src/core/ext/transport/chttp2/client/authority.cc',
    'src/core/ext/transport/chttp2/client/chttp2_connector.cc',
    'src/core/ext/transport/chttp2/client/insecure/channel_create.cc',
    'src/core/ext/transport/chttp2/client/insecure/channel_create_posix.cc',
    'src/core/ext/transport/chttp2/client/secure/secure_channel_create.cc',
    'src/core/ext/transport/chttp2/server/chttp2_server.cc',
    'src/core/ext/transport/chttp2/server/insecure/server_chttp2.cc',
    'src/core/ext/transport/chttp2/server/insecure/server_chttp2_posix.cc',
    'src/core/ext/transport/chttp2/server/secure/server_secure_chttp2.cc',
    'src/core/ext/transport/chttp2/transport/bin_decoder.cc',
    'src/core/ext/transport/chttp2/transport/bin_encoder.cc',
    'src/core/ext/transport/chttp2/transport/chttp2_plugin.cc',
    'src/core/ext/transport/chttp2/transport/chttp2_slice_allocator.cc',
    'src/core/ext/transport/chttp2/transport/chttp2_transport.cc',
    'src/core/ext/transport/chttp2/transport/context_list.cc',
    'src/core/ext/transport/chttp2/transport/flow_control.cc',
    'src/core/ext/transport/chttp2/transport/frame_data.cc',
    'src/core/ext/transport/chttp2/transport/frame_goaway.cc',
    'src/core/ext/transport/chttp2/transport/frame_ping.cc',
    'src/core/ext/transport/chttp2/transport/frame_rst_stream.cc',
    'src/core/ext/transport/chttp2/transport/frame_settings.cc',
    'src/core/ext/transport/chttp2/transport/frame_window_update.cc',
    'src/core/ext/transport/chttp2/transport/hpack_encoder.cc',
    'src/core/ext/transport/chttp2/transport/hpack_encoder_table.cc',
    'src/core/ext/transport/chttp2/transport/hpack_parser.cc',
    'src/core/ext/transport/chttp2/transport/hpack_parser_table.cc',
    'src/core/ext/transport/chttp2/transport/hpack_utils.cc',
    'src/core/ext/transport/chttp2/transport/http2_settings.cc',
    'src/core/ext/transport/chttp2/transport/huffsyms.cc',
    'src/core/ext/transport/chttp2/transport/incoming_metadata.cc',
    'src/core/ext/transport/chttp2/transport/parsing.cc',
    'src/core/ext/transport/chttp2/transport/stream_lists.cc',
    'src/core/ext/transport/chttp2/transport/stream_map.cc',
    'src/core/ext/transport/chttp2/transport/varint.cc',
    'src/core/ext/transport/chttp2/transport/writing.cc',
    'src/core/ext/transport/inproc/inproc_plugin.cc',
    'src/core/ext/transport/inproc/inproc_transport.cc',
    'src/core/ext/upb-generated/envoy/admin/v3/config_dump.upb.c',
    'src/core/ext/upb-generated/envoy/annotations/deprecation.upb.c',
    'src/core/ext/upb-generated/envoy/annotations/resource.upb.c',
    'src/core/ext/upb-generated/envoy/config/accesslog/v3/accesslog.upb.c',
    'src/core/ext/upb-generated/envoy/config/bootstrap/v3/bootstrap.upb.c',
    'src/core/ext/upb-generated/envoy/config/cluster/v3/circuit_breaker.upb.c',
    'src/core/ext/upb-generated/envoy/config/cluster/v3/cluster.upb.c',
    'src/core/ext/upb-generated/envoy/config/cluster/v3/filter.upb.c',
    'src/core/ext/upb-generated/envoy/config/cluster/v3/outlier_detection.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/address.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/backoff.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/base.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/config_source.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/event_service_config.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/extension.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/grpc_service.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/health_check.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/http_uri.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/protocol.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/proxy_protocol.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/resolver.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/socket_option.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/substitution_format_string.upb.c',
    'src/core/ext/upb-generated/envoy/config/core/v3/udp_socket_config.upb.c',
    'src/core/ext/upb-generated/envoy/config/endpoint/v3/endpoint.upb.c',
    'src/core/ext/upb-generated/envoy/config/endpoint/v3/endpoint_components.upb.c',
    'src/core/ext/upb-generated/envoy/config/endpoint/v3/load_report.upb.c',
    'src/core/ext/upb-generated/envoy/config/listener/v3/api_listener.upb.c',
    'src/core/ext/upb-generated/envoy/config/listener/v3/listener.upb.c',
    'src/core/ext/upb-generated/envoy/config/listener/v3/listener_components.upb.c',
    'src/core/ext/upb-generated/envoy/config/listener/v3/quic_config.upb.c',
    'src/core/ext/upb-generated/envoy/config/listener/v3/udp_listener_config.upb.c',
    'src/core/ext/upb-generated/envoy/config/metrics/v3/stats.upb.c',
    'src/core/ext/upb-generated/envoy/config/overload/v3/overload.upb.c',
    'src/core/ext/upb-generated/envoy/config/rbac/v3/rbac.upb.c',
    'src/core/ext/upb-generated/envoy/config/route/v3/route.upb.c',
    'src/core/ext/upb-generated/envoy/config/route/v3/route_components.upb.c',
    'src/core/ext/upb-generated/envoy/config/route/v3/scoped_route.upb.c',
    'src/core/ext/upb-generated/envoy/config/trace/v3/http_tracer.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/clusters/aggregate/v3/cluster.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/filters/common/fault/v3/fault.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/filters/http/fault/v3/fault.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/filters/http/router/v3/router.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/transport_sockets/tls/v3/cert.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/transport_sockets/tls/v3/common.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/transport_sockets/tls/v3/secret.upb.c',
    'src/core/ext/upb-generated/envoy/extensions/transport_sockets/tls/v3/tls.upb.c',
    'src/core/ext/upb-generated/envoy/service/cluster/v3/cds.upb.c',
    'src/core/ext/upb-generated/envoy/service/discovery/v3/ads.upb.c',
    'src/core/ext/upb-generated/envoy/service/discovery/v3/discovery.upb.c',
    'src/core/ext/upb-generated/envoy/service/endpoint/v3/eds.upb.c',
    'src/core/ext/upb-generated/envoy/service/listener/v3/lds.upb.c',
    'src/core/ext/upb-generated/envoy/service/load_stats/v3/lrs.upb.c',
    'src/core/ext/upb-generated/envoy/service/route/v3/rds.upb.c',
    'src/core/ext/upb-generated/envoy/service/route/v3/srds.upb.c',
    'src/core/ext/upb-generated/envoy/service/status/v3/csds.upb.c',
    'src/core/ext/upb-generated/envoy/type/http/v3/path_transformation.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/metadata.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/node.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/number.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/path.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/regex.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/string.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/struct.upb.c',
    'src/core/ext/upb-generated/envoy/type/matcher/v3/value.upb.c',
    'src/core/ext/upb-generated/envoy/type/metadata/v3/metadata.upb.c',
    'src/core/ext/upb-generated/envoy/type/tracing/v3/custom_tag.upb.c',
    'src/core/ext/upb-generated/envoy/type/v3/http.upb.c',
    'src/core/ext/upb-generated/envoy/type/v3/percent.upb.c',
    'src/core/ext/upb-generated/envoy/type/v3/range.upb.c',
    'src/core/ext/upb-generated/envoy/type/v3/semantic_version.upb.c',
    'src/core/ext/upb-generated/google/api/annotations.upb.c',
    'src/core/ext/upb-generated/google/api/expr/v1alpha1/checked.upb.c',
    'src/core/ext/upb-generated/google/api/expr/v1alpha1/syntax.upb.c',
    'src/core/ext/upb-generated/google/api/http.upb.c',
    'src/core/ext/upb-generated/google/protobuf/any.upb.c',
    'src/core/ext/upb-generated/google/protobuf/descriptor.upb.c',
    'src/core/ext/upb-generated/google/protobuf/duration.upb.c',
    'src/core/ext/upb-generated/google/protobuf/empty.upb.c',
    'src/core/ext/upb-generated/google/protobuf/struct.upb.c',
    'src/core/ext/upb-generated/google/protobuf/timestamp.upb.c',
    'src/core/ext/upb-generated/google/protobuf/wrappers.upb.c',
    'src/core/ext/upb-generated/google/rpc/status.upb.c',
    'src/core/ext/upb-generated/src/proto/grpc/gcp/altscontext.upb.c',
    'src/core/ext/upb-generated/src/proto/grpc/gcp/handshaker.upb.c',
    'src/core/ext/upb-generated/src/proto/grpc/gcp/transport_security_common.upb.c',
    'src/core/ext/upb-generated/src/proto/grpc/health/v1/health.upb.c',
    'src/core/ext/upb-generated/src/proto/grpc/lb/v1/load_balancer.upb.c',
    'src/core/ext/upb-generated/udpa/annotations/migrate.upb.c',
    'src/core/ext/upb-generated/udpa/annotations/security.upb.c',
    'src/core/ext/upb-generated/udpa/annotations/sensitive.upb.c',
    'src/core/ext/upb-generated/udpa/annotations/status.upb.c',
    'src/core/ext/upb-generated/udpa/annotations/versioning.upb.c',
    'src/core/ext/upb-generated/udpa/data/orca/v1/orca_load_report.upb.c',
    'src/core/ext/upb-generated/udpa/type/v1/typed_struct.upb.c',
    'src/core/ext/upb-generated/validate/validate.upb.c',
    'src/core/ext/upb-generated/xds/core/v3/authority.upb.c',
    'src/core/ext/upb-generated/xds/core/v3/collection_entry.upb.c',
    'src/core/ext/upb-generated/xds/core/v3/context_params.upb.c',
    'src/core/ext/upb-generated/xds/core/v3/resource.upb.c',
    'src/core/ext/upb-generated/xds/core/v3/resource_locator.upb.c',
    'src/core/ext/upb-generated/xds/core/v3/resource_name.upb.c',
    'src/core/ext/upbdefs-generated/envoy/admin/v3/config_dump.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/annotations/deprecation.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/annotations/resource.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/accesslog/v3/accesslog.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/bootstrap/v3/bootstrap.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/cluster/v3/circuit_breaker.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/cluster/v3/cluster.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/cluster/v3/filter.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/cluster/v3/outlier_detection.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/address.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/backoff.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/base.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/config_source.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/event_service_config.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/extension.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/grpc_service.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/health_check.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/http_uri.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/protocol.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/proxy_protocol.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/resolver.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/socket_option.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/substitution_format_string.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/core/v3/udp_socket_config.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/endpoint/v3/endpoint.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/endpoint/v3/endpoint_components.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/endpoint/v3/load_report.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/listener/v3/api_listener.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/listener/v3/listener.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/listener/v3/listener_components.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/listener/v3/quic_config.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/listener/v3/udp_listener_config.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/metrics/v3/stats.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/overload/v3/overload.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/route/v3/route.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/route/v3/route_components.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/route/v3/scoped_route.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/config/trace/v3/http_tracer.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/clusters/aggregate/v3/cluster.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/filters/common/fault/v3/fault.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/filters/http/fault/v3/fault.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/filters/http/router/v3/router.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/transport_sockets/tls/v3/cert.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/transport_sockets/tls/v3/common.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/transport_sockets/tls/v3/secret.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/extensions/transport_sockets/tls/v3/tls.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/cluster/v3/cds.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/discovery/v3/ads.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/discovery/v3/discovery.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/endpoint/v3/eds.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/listener/v3/lds.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/load_stats/v3/lrs.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/route/v3/rds.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/route/v3/srds.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/service/status/v3/csds.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/http/v3/path_transformation.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/metadata.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/node.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/number.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/path.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/regex.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/string.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/struct.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/matcher/v3/value.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/metadata/v3/metadata.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/tracing/v3/custom_tag.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/v3/http.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/v3/percent.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/v3/range.upbdefs.c',
    'src/core/ext/upbdefs-generated/envoy/type/v3/semantic_version.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/api/annotations.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/api/http.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/protobuf/any.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/protobuf/descriptor.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/protobuf/duration.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/protobuf/empty.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/protobuf/struct.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/protobuf/timestamp.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/protobuf/wrappers.upbdefs.c',
    'src/core/ext/upbdefs-generated/google/rpc/status.upbdefs.c',
    'src/core/ext/upbdefs-generated/udpa/annotations/migrate.upbdefs.c',
    'src/core/ext/upbdefs-generated/udpa/annotations/security.upbdefs.c',
    'src/core/ext/upbdefs-generated/udpa/annotations/sensitive.upbdefs.c',
    'src/core/ext/upbdefs-generated/udpa/annotations/status.upbdefs.c',
    'src/core/ext/upbdefs-generated/udpa/annotations/versioning.upbdefs.c',
    'src/core/ext/upbdefs-generated/udpa/type/v1/typed_struct.upbdefs.c',
    'src/core/ext/upbdefs-generated/validate/validate.upbdefs.c',
    'src/core/ext/upbdefs-generated/xds/core/v3/authority.upbdefs.c',
    'src/core/ext/upbdefs-generated/xds/core/v3/collection_entry.upbdefs.c',
    'src/core/ext/upbdefs-generated/xds/core/v3/context_params.upbdefs.c',
    'src/core/ext/upbdefs-generated/xds/core/v3/resource.upbdefs.c',
    'src/core/ext/upbdefs-generated/xds/core/v3/resource_locator.upbdefs.c',
    'src/core/ext/upbdefs-generated/xds/core/v3/resource_name.upbdefs.c',
    'src/core/ext/xds/certificate_provider_registry.cc',
    'src/core/ext/xds/certificate_provider_store.cc',
    'src/core/ext/xds/file_watcher_certificate_provider_factory.cc',
    'src/core/ext/xds/xds_api.cc',
    'src/core/ext/xds/xds_bootstrap.cc',
    'src/core/ext/xds/xds_certificate_provider.cc',
    'src/core/ext/xds/xds_client.cc',
    'src/core/ext/xds/xds_client_stats.cc',
    'src/core/ext/xds/xds_http_fault_filter.cc',
    'src/core/ext/xds/xds_http_filters.cc',
    'src/core/ext/xds/xds_server_config_fetcher.cc',
    'src/core/lib/address_utils/parse_address.cc',
    'src/core/lib/address_utils/sockaddr_utils.cc',
    'src/core/lib/avl/avl.cc',
    'src/core/lib/backoff/backoff.cc',
    'src/core/lib/channel/channel_args.cc',
    'src/core/lib/channel/channel_stack.cc',
    'src/core/lib/channel/channel_stack_builder.cc',
    'src/core/lib/channel/channel_trace.cc',
    'src/core/lib/channel/channelz.cc',
    'src/core/lib/channel/channelz_registry.cc',
    'src/core/lib/channel/connected_channel.cc',
    'src/core/lib/channel/handshaker.cc',
    'src/core/lib/channel/handshaker_registry.cc',
    'src/core/lib/channel/status_util.cc',
    'src/core/lib/compression/compression.cc',
    'src/core/lib/compression/compression_args.cc',
    'src/core/lib/compression/compression_internal.cc',
    'src/core/lib/compression/message_compress.cc',
    'src/core/lib/compression/stream_compression.cc',
    'src/core/lib/compression/stream_compression_gzip.cc',
    'src/core/lib/compression/stream_compression_identity.cc',
    'src/core/lib/config/core_configuration.cc',
    'src/core/lib/debug/stats.cc',
    'src/core/lib/debug/stats_data.cc',
    'src/core/lib/debug/trace.cc',
    'src/core/lib/event_engine/endpoint_config.cc',
    'src/core/lib/event_engine/event_engine.cc',
    'src/core/lib/event_engine/sockaddr.cc',
    'src/core/lib/gpr/alloc.cc',
    'src/core/lib/gpr/atm.cc',
    'src/core/lib/gpr/cpu_iphone.cc',
    'src/core/lib/gpr/cpu_linux.cc',
    'src/core/lib/gpr/cpu_posix.cc',
    'src/core/lib/gpr/cpu_windows.cc',
    'src/core/lib/gpr/env_linux.cc',
    'src/core/lib/gpr/env_posix.cc',
    'src/core/lib/gpr/env_windows.cc',
    'src/core/lib/gpr/log.cc',
    'src/core/lib/gpr/log_android.cc',
    'src/core/lib/gpr/log_linux.cc',
    'src/core/lib/gpr/log_posix.cc',
    'src/core/lib/gpr/log_windows.cc',
    'src/core/lib/gpr/murmur_hash.cc',
    'src/core/lib/gpr/string.cc',
    'src/core/lib/gpr/string_posix.cc',
    'src/core/lib/gpr/string_util_windows.cc',
    'src/core/lib/gpr/string_windows.cc',
    'src/core/lib/gpr/sync.cc',
    'src/core/lib/gpr/sync_abseil.cc',
    'src/core/lib/gpr/sync_posix.cc',
    'src/core/lib/gpr/sync_windows.cc',
    'src/core/lib/gpr/time.cc',
    'src/core/lib/gpr/time_posix.cc',
    'src/core/lib/gpr/time_precise.cc',
    'src/core/lib/gpr/time_windows.cc',
    'src/core/lib/gpr/tmpfile_msys.cc',
    'src/core/lib/gpr/tmpfile_posix.cc',
    'src/core/lib/gpr/tmpfile_windows.cc',
    'src/core/lib/gpr/wrap_memcpy.cc',
    'src/core/lib/gprpp/arena.cc',
    'src/core/lib/gprpp/examine_stack.cc',
    'src/core/lib/gprpp/fork.cc',
    'src/core/lib/gprpp/global_config_env.cc',
    'src/core/lib/gprpp/host_port.cc',
    'src/core/lib/gprpp/mpscq.cc',
    'src/core/lib/gprpp/stat_posix.cc',
    'src/core/lib/gprpp/stat_windows.cc',
    'src/core/lib/gprpp/status_helper.cc',
    'src/core/lib/gprpp/thd_posix.cc',
    'src/core/lib/gprpp/thd_windows.cc',
    'src/core/lib/gprpp/time_util.cc',
    'src/core/lib/http/format_request.cc',
    'src/core/lib/http/httpcli.cc',
    'src/core/lib/http/httpcli_security_connector.cc',
    'src/core/lib/http/parser.cc',
    'src/core/lib/iomgr/buffer_list.cc',
    'src/core/lib/iomgr/call_combiner.cc',
    'src/core/lib/iomgr/cfstream_handle.cc',
    'src/core/lib/iomgr/combiner.cc',
    'src/core/lib/iomgr/dualstack_socket_posix.cc',
    'src/core/lib/iomgr/endpoint.cc',
    'src/core/lib/iomgr/endpoint_cfstream.cc',
    'src/core/lib/iomgr/endpoint_pair_event_engine.cc',
    'src/core/lib/iomgr/endpoint_pair_posix.cc',
    'src/core/lib/iomgr/endpoint_pair_windows.cc',
    'src/core/lib/iomgr/error.cc',
    'src/core/lib/iomgr/error_cfstream.cc',
    'src/core/lib/iomgr/ev_apple.cc',
    'src/core/lib/iomgr/ev_epoll1_linux.cc',
    'src/core/lib/iomgr/ev_epollex_linux.cc',
    'src/core/lib/iomgr/ev_poll_posix.cc',
    'src/core/lib/iomgr/ev_posix.cc',
    'src/core/lib/iomgr/ev_windows.cc',
    'src/core/lib/iomgr/event_engine/closure.cc',
    'src/core/lib/iomgr/event_engine/endpoint.cc',
    'src/core/lib/iomgr/event_engine/iomgr.cc',
    'src/core/lib/iomgr/event_engine/pollset.cc',
    'src/core/lib/iomgr/event_engine/resolved_address_internal.cc',
    'src/core/lib/iomgr/event_engine/resolver.cc',
    'src/core/lib/iomgr/event_engine/tcp.cc',
    'src/core/lib/iomgr/event_engine/timer.cc',
    'src/core/lib/iomgr/exec_ctx.cc',
    'src/core/lib/iomgr/executor.cc',
    'src/core/lib/iomgr/executor/mpmcqueue.cc',
    'src/core/lib/iomgr/executor/threadpool.cc',
    'src/core/lib/iomgr/fork_posix.cc',
    'src/core/lib/iomgr/fork_windows.cc',
    'src/core/lib/iomgr/gethostname_fallback.cc',
    'src/core/lib/iomgr/gethostname_host_name_max.cc',
    'src/core/lib/iomgr/gethostname_sysconf.cc',
    'src/core/lib/iomgr/grpc_if_nametoindex_posix.cc',
    'src/core/lib/iomgr/grpc_if_nametoindex_unsupported.cc',
    'src/core/lib/iomgr/internal_errqueue.cc',
    'src/core/lib/iomgr/iocp_windows.cc',
    'src/core/lib/iomgr/iomgr.cc',
    'src/core/lib/iomgr/iomgr_custom.cc',
    'src/core/lib/iomgr/iomgr_internal.cc',
    'src/core/lib/iomgr/iomgr_posix.cc',
    'src/core/lib/iomgr/iomgr_posix_cfstream.cc',
    'src/core/lib/iomgr/iomgr_windows.cc',
    'src/core/lib/iomgr/is_epollexclusive_available.cc',
    'src/core/lib/iomgr/load_file.cc',
    'src/core/lib/iomgr/lockfree_event.cc',
    'src/core/lib/iomgr/polling_entity.cc',
    'src/core/lib/iomgr/pollset.cc',
    'src/core/lib/iomgr/pollset_custom.cc',
    'src/core/lib/iomgr/pollset_set.cc',
    'src/core/lib/iomgr/pollset_set_custom.cc',
    'src/core/lib/iomgr/pollset_set_windows.cc',
    'src/core/lib/iomgr/pollset_windows.cc',
    'src/core/lib/iomgr/resolve_address.cc',
    'src/core/lib/iomgr/resolve_address_custom.cc',
    'src/core/lib/iomgr/resolve_address_posix.cc',
    'src/core/lib/iomgr/resolve_address_windows.cc',
    'src/core/lib/iomgr/resource_quota.cc',
    'src/core/lib/iomgr/socket_factory_posix.cc',
    'src/core/lib/iomgr/socket_mutator.cc',
    'src/core/lib/iomgr/socket_utils_common_posix.cc',
    'src/core/lib/iomgr/socket_utils_linux.cc',
    'src/core/lib/iomgr/socket_utils_posix.cc',
    'src/core/lib/iomgr/socket_utils_windows.cc',
    'src/core/lib/iomgr/socket_windows.cc',
    'src/core/lib/iomgr/tcp_client.cc',
    'src/core/lib/iomgr/tcp_client_cfstream.cc',
    'src/core/lib/iomgr/tcp_client_custom.cc',
    'src/core/lib/iomgr/tcp_client_posix.cc',
    'src/core/lib/iomgr/tcp_client_windows.cc',
    'src/core/lib/iomgr/tcp_custom.cc',
    'src/core/lib/iomgr/tcp_posix.cc',
    'src/core/lib/iomgr/tcp_server.cc',
    'src/core/lib/iomgr/tcp_server_custom.cc',
    'src/core/lib/iomgr/tcp_server_posix.cc',
    'src/core/lib/iomgr/tcp_server_utils_posix_common.cc',
    'src/core/lib/iomgr/tcp_server_utils_posix_ifaddrs.cc',
    'src/core/lib/iomgr/tcp_server_utils_posix_noifaddrs.cc',
    'src/core/lib/iomgr/tcp_server_windows.cc',
    'src/core/lib/iomgr/tcp_windows.cc',
    'src/core/lib/iomgr/time_averaged_stats.cc',
    'src/core/lib/iomgr/timer.cc',
    'src/core/lib/iomgr/timer_custom.cc',
    'src/core/lib/iomgr/timer_generic.cc',
    'src/core/lib/iomgr/timer_heap.cc',
    'src/core/lib/iomgr/timer_manager.cc',
    'src/core/lib/iomgr/udp_server.cc',
    'src/core/lib/iomgr/unix_sockets_posix.cc',
    'src/core/lib/iomgr/unix_sockets_posix_noop.cc',
    'src/core/lib/iomgr/wakeup_fd_eventfd.cc',
    'src/core/lib/iomgr/wakeup_fd_nospecial.cc',
    'src/core/lib/iomgr/wakeup_fd_pipe.cc',
    'src/core/lib/iomgr/wakeup_fd_posix.cc',
    'src/core/lib/iomgr/work_serializer.cc',
    'src/core/lib/json/json_reader.cc',
    'src/core/lib/json/json_util.cc',
    'src/core/lib/json/json_writer.cc',
    'src/core/lib/matchers/matchers.cc',
    'src/core/lib/profiling/basic_timers.cc',
    'src/core/lib/profiling/stap_timers.cc',
    'src/core/lib/security/authorization/authorization_policy_provider_vtable.cc',
    'src/core/lib/security/authorization/evaluate_args.cc',
    'src/core/lib/security/authorization/sdk_server_authz_filter.cc',
    'src/core/lib/security/context/security_context.cc',
    'src/core/lib/security/credentials/alts/alts_credentials.cc',
    'src/core/lib/security/credentials/alts/check_gcp_environment.cc',
    'src/core/lib/security/credentials/alts/check_gcp_environment_linux.cc',
    'src/core/lib/security/credentials/alts/check_gcp_environment_no_op.cc',
    'src/core/lib/security/credentials/alts/check_gcp_environment_windows.cc',
    'src/core/lib/security/credentials/alts/grpc_alts_credentials_client_options.cc',
    'src/core/lib/security/credentials/alts/grpc_alts_credentials_options.cc',
    'src/core/lib/security/credentials/alts/grpc_alts_credentials_server_options.cc',
    'src/core/lib/security/credentials/composite/composite_credentials.cc',
    'src/core/lib/security/credentials/credentials.cc',
    'src/core/lib/security/credentials/credentials_metadata.cc',
    'src/core/lib/security/credentials/external/aws_external_account_credentials.cc',
    'src/core/lib/security/credentials/external/aws_request_signer.cc',
    'src/core/lib/security/credentials/external/external_account_credentials.cc',
    'src/core/lib/security/credentials/external/file_external_account_credentials.cc',
    'src/core/lib/security/credentials/external/url_external_account_credentials.cc',
    'src/core/lib/security/credentials/fake/fake_credentials.cc',
    'src/core/lib/security/credentials/google_default/credentials_generic.cc',
    'src/core/lib/security/credentials/google_default/google_default_credentials.cc',
    'src/core/lib/security/credentials/iam/iam_credentials.cc',
    'src/core/lib/security/credentials/insecure/insecure_credentials.cc',
    'src/core/lib/security/credentials/jwt/json_token.cc',
    'src/core/lib/security/credentials/jwt/jwt_credentials.cc',
    'src/core/lib/security/credentials/jwt/jwt_verifier.cc',
    'src/core/lib/security/credentials/local/local_credentials.cc',
    'src/core/lib/security/credentials/oauth2/oauth2_credentials.cc',
    'src/core/lib/security/credentials/plugin/plugin_credentials.cc',
    'src/core/lib/security/credentials/ssl/ssl_credentials.cc',
    'src/core/lib/security/credentials/tls/grpc_tls_certificate_distributor.cc',
    'src/core/lib/security/credentials/tls/grpc_tls_certificate_provider.cc',
    'src/core/lib/security/credentials/tls/grpc_tls_credentials_options.cc',
    'src/core/lib/security/credentials/tls/tls_credentials.cc',
    'src/core/lib/security/credentials/tls/tls_utils.cc',
    'src/core/lib/security/credentials/xds/xds_credentials.cc',
    'src/core/lib/security/security_connector/alts/alts_security_connector.cc',
    'src/core/lib/security/security_connector/fake/fake_security_connector.cc',
    'src/core/lib/security/security_connector/insecure/insecure_security_connector.cc',
    'src/core/lib/security/security_connector/load_system_roots_fallback.cc',
    'src/core/lib/security/security_connector/load_system_roots_linux.cc',
    'src/core/lib/security/security_connector/local/local_security_connector.cc',
    'src/core/lib/security/security_connector/security_connector.cc',
    'src/core/lib/security/security_connector/ssl/ssl_security_connector.cc',
    'src/core/lib/security/security_connector/ssl_utils.cc',
    'src/core/lib/security/security_connector/ssl_utils_config.cc',
    'src/core/lib/security/security_connector/tls/tls_security_connector.cc',
    'src/core/lib/security/transport/client_auth_filter.cc',
    'src/core/lib/security/transport/secure_endpoint.cc',
    'src/core/lib/security/transport/security_handshaker.cc',
    'src/core/lib/security/transport/server_auth_filter.cc',
    'src/core/lib/security/transport/tsi_error.cc',
    'src/core/lib/security/util/json_util.cc',
    'src/core/lib/slice/b64.cc',
    'src/core/lib/slice/percent_encoding.cc',
    'src/core/lib/slice/slice.cc',
    'src/core/lib/slice/slice_buffer.cc',
    'src/core/lib/slice/slice_intern.cc',
    'src/core/lib/slice/slice_string_helpers.cc',
    'src/core/lib/surface/api_trace.cc',
    'src/core/lib/surface/byte_buffer.cc',
    'src/core/lib/surface/byte_buffer_reader.cc',
    'src/core/lib/surface/call.cc',
    'src/core/lib/surface/call_details.cc',
    'src/core/lib/surface/call_log_batch.cc',
    'src/core/lib/surface/channel.cc',
    'src/core/lib/surface/channel_init.cc',
    'src/core/lib/surface/channel_ping.cc',
    'src/core/lib/surface/channel_stack_type.cc',
    'src/core/lib/surface/completion_queue.cc',
    'src/core/lib/surface/completion_queue_factory.cc',
    'src/core/lib/surface/event_string.cc',
    'src/core/lib/surface/init.cc',
    'src/core/lib/surface/init_secure.cc',
    'src/core/lib/surface/lame_client.cc',
    'src/core/lib/surface/metadata_array.cc',
    'src/core/lib/surface/server.cc',
    'src/core/lib/surface/validate_metadata.cc',
    'src/core/lib/surface/version.cc',
    'src/core/lib/transport/authority_override.cc',
    'src/core/lib/transport/bdp_estimator.cc',
    'src/core/lib/transport/byte_stream.cc',
    'src/core/lib/transport/connectivity_state.cc',
    'src/core/lib/transport/error_utils.cc',
    'src/core/lib/transport/metadata.cc',
    'src/core/lib/transport/metadata_batch.cc',
    'src/core/lib/transport/pid_controller.cc',
    'src/core/lib/transport/static_metadata.cc',
    'src/core/lib/transport/status_conversion.cc',
    'src/core/lib/transport/status_metadata.cc',
    'src/core/lib/transport/timeout_encoding.cc',
    'src/core/lib/transport/transport.cc',
    'src/core/lib/transport/transport_op_string.cc',
    'src/core/lib/uri/uri_parser.cc',
    'src/core/plugin_registry/grpc_plugin_registry.cc',
    'src/core/tsi/alts/crypt/aes_gcm.cc',
    'src/core/tsi/alts/crypt/gsec.cc',
    'src/core/tsi/alts/frame_protector/alts_counter.cc',
    'src/core/tsi/alts/frame_protector/alts_crypter.cc',
    'src/core/tsi/alts/frame_protector/alts_frame_protector.cc',
    'src/core/tsi/alts/frame_protector/alts_record_protocol_crypter_common.cc',
    'src/core/tsi/alts/frame_protector/alts_seal_privacy_integrity_crypter.cc',
    'src/core/tsi/alts/frame_protector/alts_unseal_privacy_integrity_crypter.cc',
    'src/core/tsi/alts/frame_protector/frame_handler.cc',
    'src/core/tsi/alts/handshaker/alts_handshaker_client.cc',
    'src/core/tsi/alts/handshaker/alts_shared_resource.cc',
    'src/core/tsi/alts/handshaker/alts_tsi_handshaker.cc',
    'src/core/tsi/alts/handshaker/alts_tsi_utils.cc',
    'src/core/tsi/alts/handshaker/transport_security_common_api.cc',
    'src/core/tsi/alts/zero_copy_frame_protector/alts_grpc_integrity_only_record_protocol.cc',
    'src/core/tsi/alts/zero_copy_frame_protector/alts_grpc_privacy_integrity_record_protocol.cc',
    'src/core/tsi/alts/zero_copy_frame_protector/alts_grpc_record_protocol_common.cc',
    'src/core/tsi/alts/zero_copy_frame_protector/alts_iovec_record_protocol.cc',
    'src/core/tsi/alts/zero_copy_frame_protector/alts_zero_copy_grpc_protector.cc',
    'src/core/tsi/fake_transport_security.cc',
    'src/core/tsi/local_transport_security.cc',
    'src/core/tsi/ssl/session_cache/ssl_session_boringssl.cc',
    'src/core/tsi/ssl/session_cache/ssl_session_cache.cc',
    'src/core/tsi/ssl/session_cache/ssl_session_openssl.cc',
    'src/core/tsi/ssl_transport_security.cc',
    'src/core/tsi/transport_security.cc',
    'src/core/tsi/transport_security_grpc.cc',
    'third_party/abseil-cpp/absl/base/internal/cycleclock.cc',
    'third_party/abseil-cpp/absl/base/internal/exponential_biased.cc',
    'third_party/abseil-cpp/absl/base/internal/low_level_alloc.cc',
    'third_party/abseil-cpp/absl/base/internal/raw_logging.cc',
    'third_party/abseil-cpp/absl/base/internal/spinlock.cc',
    'third_party/abseil-cpp/absl/base/internal/spinlock_wait.cc',
    'third_party/abseil-cpp/absl/base/internal/sysinfo.cc',
    'third_party/abseil-cpp/absl/base/internal/thread_identity.cc',
    'third_party/abseil-cpp/absl/base/internal/throw_delegate.cc',
    'third_party/abseil-cpp/absl/base/internal/unscaledcycleclock.cc',
    'third_party/abseil-cpp/absl/base/log_severity.cc',
    'third_party/abseil-cpp/absl/container/internal/hashtablez_sampler.cc',
    'third_party/abseil-cpp/absl/container/internal/hashtablez_sampler_force_weak_definition.cc',
    'third_party/abseil-cpp/absl/container/internal/raw_hash_set.cc',
    'third_party/abseil-cpp/absl/debugging/internal/address_is_readable.cc',
    'third_party/abseil-cpp/absl/debugging/internal/demangle.cc',
    'third_party/abseil-cpp/absl/debugging/internal/elf_mem_image.cc',
    'third_party/abseil-cpp/absl/debugging/internal/vdso_support.cc',
    'third_party/abseil-cpp/absl/debugging/stacktrace.cc',
    'third_party/abseil-cpp/absl/debugging/symbolize.cc',
    'third_party/abseil-cpp/absl/hash/internal/city.cc',
    'third_party/abseil-cpp/absl/hash/internal/hash.cc',
    'third_party/abseil-cpp/absl/hash/internal/wyhash.cc',
    'third_party/abseil-cpp/absl/numeric/int128.cc',
    'third_party/abseil-cpp/absl/status/status.cc',
    'third_party/abseil-cpp/absl/status/status_payload_printer.cc',
    'third_party/abseil-cpp/absl/status/statusor.cc',
    'third_party/abseil-cpp/absl/strings/ascii.cc',
    'third_party/abseil-cpp/absl/strings/charconv.cc',
    'third_party/abseil-cpp/absl/strings/cord.cc',
    'third_party/abseil-cpp/absl/strings/escaping.cc',
    'third_party/abseil-cpp/absl/strings/internal/charconv_bigint.cc',
    'third_party/abseil-cpp/absl/strings/internal/charconv_parse.cc',
    'third_party/abseil-cpp/absl/strings/internal/cord_internal.cc',
    'third_party/abseil-cpp/absl/strings/internal/cord_rep_ring.cc',
    'third_party/abseil-cpp/absl/strings/internal/escaping.cc',
    'third_party/abseil-cpp/absl/strings/internal/memutil.cc',
    'third_party/abseil-cpp/absl/strings/internal/ostringstream.cc',
    'third_party/abseil-cpp/absl/strings/internal/str_format/arg.cc',
    'third_party/abseil-cpp/absl/strings/internal/str_format/bind.cc',
    'third_party/abseil-cpp/absl/strings/internal/str_format/extension.cc',
    'third_party/abseil-cpp/absl/strings/internal/str_format/float_conversion.cc',
    'third_party/abseil-cpp/absl/strings/internal/str_format/output.cc',
    'third_party/abseil-cpp/absl/strings/internal/str_format/parser.cc',
    'third_party/abseil-cpp/absl/strings/internal/utf8.cc',
    'third_party/abseil-cpp/absl/strings/match.cc',
    'third_party/abseil-cpp/absl/strings/numbers.cc',
    'third_party/abseil-cpp/absl/strings/str_cat.cc',
    'third_party/abseil-cpp/absl/strings/str_replace.cc',
    'third_party/abseil-cpp/absl/strings/str_split.cc',
    'third_party/abseil-cpp/absl/strings/string_view.cc',
    'third_party/abseil-cpp/absl/strings/substitute.cc',
    'third_party/abseil-cpp/absl/synchronization/barrier.cc',
    'third_party/abseil-cpp/absl/synchronization/blocking_counter.cc',
    'third_party/abseil-cpp/absl/synchronization/internal/create_thread_identity.cc',
    'third_party/abseil-cpp/absl/synchronization/internal/graphcycles.cc',
    'third_party/abseil-cpp/absl/synchronization/internal/per_thread_sem.cc',
    'third_party/abseil-cpp/absl/synchronization/internal/waiter.cc',
    'third_party/abseil-cpp/absl/synchronization/mutex.cc',
    'third_party/abseil-cpp/absl/synchronization/notification.cc',
    'third_party/abseil-cpp/absl/time/civil_time.cc',
    'third_party/abseil-cpp/absl/time/clock.cc',
    'third_party/abseil-cpp/absl/time/duration.cc',
    'third_party/abseil-cpp/absl/time/format.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/civil_time_detail.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_fixed.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_format.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_if.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_impl.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_info.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_libc.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_lookup.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/time_zone_posix.cc',
    'third_party/abseil-cpp/absl/time/internal/cctz/src/zone_info_source.cc',
    'third_party/abseil-cpp/absl/time/time.cc',
    'third_party/abseil-cpp/absl/types/bad_optional_access.cc',
    'third_party/abseil-cpp/absl/types/bad_variant_access.cc',
    'third_party/address_sorting/address_sorting.c',
    'third_party/address_sorting/address_sorting_posix.c',
    'third_party/address_sorting/address_sorting_windows.c',
    'third_party/boringssl-with-bazel/err_data.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_bitstr.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_bool.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_d2i_fp.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_dup.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_enum.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_gentm.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_i2d_fp.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_int.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_mbstr.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_object.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_octet.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_print.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_strnid.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_time.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_type.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_utctm.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/a_utf8.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/asn1_lib.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/asn1_par.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/asn_pack.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/f_enum.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/f_int.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/f_string.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/tasn_dec.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/tasn_enc.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/tasn_fre.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/tasn_new.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/tasn_typ.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/tasn_utl.c',
    'third_party/boringssl-with-bazel/src/crypto/asn1/time_support.c',
    'third_party/boringssl-with-bazel/src/crypto/base64/base64.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/bio.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/bio_mem.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/connect.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/fd.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/file.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/hexdump.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/pair.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/printf.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/socket.c',
    'third_party/boringssl-with-bazel/src/crypto/bio/socket_helper.c',
    'third_party/boringssl-with-bazel/src/crypto/blake2/blake2.c',
    'third_party/boringssl-with-bazel/src/crypto/bn_extra/bn_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/bn_extra/convert.c',
    'third_party/boringssl-with-bazel/src/crypto/buf/buf.c',
    'third_party/boringssl-with-bazel/src/crypto/bytestring/asn1_compat.c',
    'third_party/boringssl-with-bazel/src/crypto/bytestring/ber.c',
    'third_party/boringssl-with-bazel/src/crypto/bytestring/cbb.c',
    'third_party/boringssl-with-bazel/src/crypto/bytestring/cbs.c',
    'third_party/boringssl-with-bazel/src/crypto/bytestring/unicode.c',
    'third_party/boringssl-with-bazel/src/crypto/chacha/chacha.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/cipher_extra.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/derive_key.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_aesccm.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_aesctrhmac.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_aesgcmsiv.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_chacha20poly1305.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_null.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_rc2.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_rc4.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/e_tls.c',
    'third_party/boringssl-with-bazel/src/crypto/cipher_extra/tls_cbc.c',
    'third_party/boringssl-with-bazel/src/crypto/cmac/cmac.c',
    'third_party/boringssl-with-bazel/src/crypto/conf/conf.c',
    'third_party/boringssl-with-bazel/src/crypto/cpu-aarch64-fuchsia.c',
    'third_party/boringssl-with-bazel/src/crypto/cpu-aarch64-linux.c',
    'third_party/boringssl-with-bazel/src/crypto/cpu-aarch64-win.c',
    'third_party/boringssl-with-bazel/src/crypto/cpu-arm-linux.c',
    'third_party/boringssl-with-bazel/src/crypto/cpu-arm.c',
    'third_party/boringssl-with-bazel/src/crypto/cpu-intel.c',
    'third_party/boringssl-with-bazel/src/crypto/cpu-ppc64le.c',
    'third_party/boringssl-with-bazel/src/crypto/crypto.c',
    'third_party/boringssl-with-bazel/src/crypto/curve25519/curve25519.c',
    'third_party/boringssl-with-bazel/src/crypto/curve25519/spake25519.c',
    'third_party/boringssl-with-bazel/src/crypto/dh_extra/dh_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/dh_extra/params.c',
    'third_party/boringssl-with-bazel/src/crypto/digest_extra/digest_extra.c',
    'third_party/boringssl-with-bazel/src/crypto/dsa/dsa.c',
    'third_party/boringssl-with-bazel/src/crypto/dsa/dsa_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/ec_extra/ec_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/ec_extra/ec_derive.c',
    'third_party/boringssl-with-bazel/src/crypto/ec_extra/hash_to_curve.c',
    'third_party/boringssl-with-bazel/src/crypto/ecdh_extra/ecdh_extra.c',
    'third_party/boringssl-with-bazel/src/crypto/ecdsa_extra/ecdsa_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/engine/engine.c',
    'third_party/boringssl-with-bazel/src/crypto/err/err.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/digestsign.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/evp.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/evp_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/evp_ctx.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_dsa_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_ec.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_ec_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_ed25519.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_ed25519_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_rsa.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_rsa_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_x25519.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/p_x25519_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/pbkdf.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/print.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/scrypt.c',
    'third_party/boringssl-with-bazel/src/crypto/evp/sign.c',
    'third_party/boringssl-with-bazel/src/crypto/ex_data.c',
    'third_party/boringssl-with-bazel/src/crypto/fipsmodule/bcm.c',
    'third_party/boringssl-with-bazel/src/crypto/fipsmodule/fips_shared_support.c',
    'third_party/boringssl-with-bazel/src/crypto/hkdf/hkdf.c',
    'third_party/boringssl-with-bazel/src/crypto/hpke/hpke.c',
    'third_party/boringssl-with-bazel/src/crypto/hrss/hrss.c',
    'third_party/boringssl-with-bazel/src/crypto/lhash/lhash.c',
    'third_party/boringssl-with-bazel/src/crypto/mem.c',
    'third_party/boringssl-with-bazel/src/crypto/obj/obj.c',
    'third_party/boringssl-with-bazel/src/crypto/obj/obj_xref.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_all.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_info.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_lib.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_oth.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_pk8.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_pkey.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_x509.c',
    'third_party/boringssl-with-bazel/src/crypto/pem/pem_xaux.c',
    'third_party/boringssl-with-bazel/src/crypto/pkcs7/pkcs7.c',
    'third_party/boringssl-with-bazel/src/crypto/pkcs7/pkcs7_x509.c',
    'third_party/boringssl-with-bazel/src/crypto/pkcs8/p5_pbev2.c',
    'third_party/boringssl-with-bazel/src/crypto/pkcs8/pkcs8.c',
    'third_party/boringssl-with-bazel/src/crypto/pkcs8/pkcs8_x509.c',
    'third_party/boringssl-with-bazel/src/crypto/poly1305/poly1305.c',
    'third_party/boringssl-with-bazel/src/crypto/poly1305/poly1305_arm.c',
    'third_party/boringssl-with-bazel/src/crypto/poly1305/poly1305_vec.c',
    'third_party/boringssl-with-bazel/src/crypto/pool/pool.c',
    'third_party/boringssl-with-bazel/src/crypto/rand_extra/deterministic.c',
    'third_party/boringssl-with-bazel/src/crypto/rand_extra/forkunsafe.c',
    'third_party/boringssl-with-bazel/src/crypto/rand_extra/fuchsia.c',
    'third_party/boringssl-with-bazel/src/crypto/rand_extra/passive.c',
    'third_party/boringssl-with-bazel/src/crypto/rand_extra/rand_extra.c',
    'third_party/boringssl-with-bazel/src/crypto/rand_extra/windows.c',
    'third_party/boringssl-with-bazel/src/crypto/rc4/rc4.c',
    'third_party/boringssl-with-bazel/src/crypto/refcount_c11.c',
    'third_party/boringssl-with-bazel/src/crypto/refcount_lock.c',
    'third_party/boringssl-with-bazel/src/crypto/rsa_extra/rsa_asn1.c',
    'third_party/boringssl-with-bazel/src/crypto/rsa_extra/rsa_print.c',
    'third_party/boringssl-with-bazel/src/crypto/siphash/siphash.c',
    'third_party/boringssl-with-bazel/src/crypto/stack/stack.c',
    'third_party/boringssl-with-bazel/src/crypto/thread.c',
    'third_party/boringssl-with-bazel/src/crypto/thread_none.c',
    'third_party/boringssl-with-bazel/src/crypto/thread_pthread.c',
    'third_party/boringssl-with-bazel/src/crypto/thread_win.c',
    'third_party/boringssl-with-bazel/src/crypto/trust_token/pmbtoken.c',
    'third_party/boringssl-with-bazel/src/crypto/trust_token/trust_token.c',
    'third_party/boringssl-with-bazel/src/crypto/trust_token/voprf.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/a_digest.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/a_sign.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/a_strex.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/a_verify.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/algorithm.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/asn1_gen.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/by_dir.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/by_file.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/i2d_pr.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/rsa_pss.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/t_crl.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/t_req.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/t_x509.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/t_x509a.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_att.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_cmp.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_d2.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_def.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_ext.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_lu.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_obj.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_req.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_set.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_trs.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_txt.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_v3.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_vfy.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509_vpm.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509cset.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509name.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509rset.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x509spki.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_algor.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_all.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_attrib.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_crl.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_exten.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_info.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_name.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_pkey.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_pubkey.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_req.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_sig.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_spki.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_val.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_x509.c',
    'third_party/boringssl-with-bazel/src/crypto/x509/x_x509a.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/pcy_cache.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/pcy_data.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/pcy_lib.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/pcy_map.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/pcy_node.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/pcy_tree.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_akey.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_akeya.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_alt.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_bcons.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_bitst.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_conf.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_cpols.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_crld.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_enum.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_extku.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_genn.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_ia5.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_info.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_int.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_lib.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_ncons.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_ocsp.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_pci.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_pcia.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_pcons.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_pmaps.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_prn.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_purp.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_skey.c',
    'third_party/boringssl-with-bazel/src/crypto/x509v3/v3_utl.c',
    'third_party/boringssl-with-bazel/src/ssl/bio_ssl.cc',
    'third_party/boringssl-with-bazel/src/ssl/d1_both.cc',
    'third_party/boringssl-with-bazel/src/ssl/d1_lib.cc',
    'third_party/boringssl-with-bazel/src/ssl/d1_pkt.cc',
    'third_party/boringssl-with-bazel/src/ssl/d1_srtp.cc',
    'third_party/boringssl-with-bazel/src/ssl/dtls_method.cc',
    'third_party/boringssl-with-bazel/src/ssl/dtls_record.cc',
    'third_party/boringssl-with-bazel/src/ssl/encrypted_client_hello.cc',
    'third_party/boringssl-with-bazel/src/ssl/extensions.cc',
    'third_party/boringssl-with-bazel/src/ssl/handoff.cc',
    'third_party/boringssl-with-bazel/src/ssl/handshake.cc',
    'third_party/boringssl-with-bazel/src/ssl/handshake_client.cc',
    'third_party/boringssl-with-bazel/src/ssl/handshake_server.cc',
    'third_party/boringssl-with-bazel/src/ssl/s3_both.cc',
    'third_party/boringssl-with-bazel/src/ssl/s3_lib.cc',
    'third_party/boringssl-with-bazel/src/ssl/s3_pkt.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_aead_ctx.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_asn1.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_buffer.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_cert.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_cipher.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_file.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_key_share.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_lib.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_privkey.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_session.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_stat.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_transcript.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_versions.cc',
    'third_party/boringssl-with-bazel/src/ssl/ssl_x509.cc',
    'third_party/boringssl-with-bazel/src/ssl/t1_enc.cc',
    'third_party/boringssl-with-bazel/src/ssl/tls13_both.cc',
    'third_party/boringssl-with-bazel/src/ssl/tls13_client.cc',
    'third_party/boringssl-with-bazel/src/ssl/tls13_enc.cc',
    'third_party/boringssl-with-bazel/src/ssl/tls13_server.cc',
    'third_party/boringssl-with-bazel/src/ssl/tls_method.cc',
    'third_party/boringssl-with-bazel/src/ssl/tls_record.cc',
    'third_party/cares/cares/ares__close_sockets.c',
    'third_party/cares/cares/ares__get_hostent.c',
    'third_party/cares/cares/ares__read_line.c',
    'third_party/cares/cares/ares__timeval.c',
    'third_party/cares/cares/ares_cancel.c',
    'third_party/cares/cares/ares_create_query.c',
    'third_party/cares/cares/ares_data.c',
    'third_party/cares/cares/ares_destroy.c',
    'third_party/cares/cares/ares_expand_name.c',
    'third_party/cares/cares/ares_expand_string.c',
    'third_party/cares/cares/ares_fds.c',
    'third_party/cares/cares/ares_free_hostent.c',
    'third_party/cares/cares/ares_free_string.c',
    'third_party/cares/cares/ares_getenv.c',
    'third_party/cares/cares/ares_gethostbyaddr.c',
    'third_party/cares/cares/ares_gethostbyname.c',
    'third_party/cares/cares/ares_getnameinfo.c',
    'third_party/cares/cares/ares_getopt.c',
    'third_party/cares/cares/ares_getsock.c',
    'third_party/cares/cares/ares_init.c',
    'third_party/cares/cares/ares_library_init.c',
    'third_party/cares/cares/ares_llist.c',
    'third_party/cares/cares/ares_mkquery.c',
    'third_party/cares/cares/ares_nowarn.c',
    'third_party/cares/cares/ares_options.c',
    'third_party/cares/cares/ares_parse_a_reply.c',
    'third_party/cares/cares/ares_parse_aaaa_reply.c',
    'third_party/cares/cares/ares_parse_mx_reply.c',
    'third_party/cares/cares/ares_parse_naptr_reply.c',
    'third_party/cares/cares/ares_parse_ns_reply.c',
    'third_party/cares/cares/ares_parse_ptr_reply.c',
    'third_party/cares/cares/ares_parse_soa_reply.c',
    'third_party/cares/cares/ares_parse_srv_reply.c',
    'third_party/cares/cares/ares_parse_txt_reply.c',
    'third_party/cares/cares/ares_platform.c',
    'third_party/cares/cares/ares_process.c',
    'third_party/cares/cares/ares_query.c',
    'third_party/cares/cares/ares_search.c',
    'third_party/cares/cares/ares_send.c',
    'third_party/cares/cares/ares_strcasecmp.c',
    'third_party/cares/cares/ares_strdup.c',
    'third_party/cares/cares/ares_strerror.c',
    'third_party/cares/cares/ares_strsplit.c',
    'third_party/cares/cares/ares_timeout.c',
    'third_party/cares/cares/ares_version.c',
    'third_party/cares/cares/ares_writev.c',
    'third_party/cares/cares/bitncmp.c',
    'third_party/cares/cares/inet_net_pton.c',
    'third_party/cares/cares/inet_ntop.c',
    'third_party/cares/cares/windows_port.c',
    'third_party/re2/re2/bitstate.cc',
    'third_party/re2/re2/compile.cc',
    'third_party/re2/re2/dfa.cc',
    'third_party/re2/re2/filtered_re2.cc',
    'third_party/re2/re2/mimics_pcre.cc',
    'third_party/re2/re2/nfa.cc',
    'third_party/re2/re2/onepass.cc',
    'third_party/re2/re2/parse.cc',
    'third_party/re2/re2/perl_groups.cc',
    'third_party/re2/re2/prefilter.cc',
    'third_party/re2/re2/prefilter_tree.cc',
    'third_party/re2/re2/prog.cc',
    'third_party/re2/re2/re2.cc',
    'third_party/re2/re2/regexp.cc',
    'third_party/re2/re2/set.cc',
    'third_party/re2/re2/simplify.cc',
    'third_party/re2/re2/stringpiece.cc',
    'third_party/re2/re2/tostring.cc',
    'third_party/re2/re2/unicode_casefold.cc',
    'third_party/re2/re2/unicode_groups.cc',
    'third_party/re2/util/pcre.cc',
    'third_party/re2/util/rune.cc',
    'third_party/re2/util/strutil.cc',
    'third_party/upb/upb/decode.c',
    'third_party/upb/upb/decode_fast.c',
    'third_party/upb/upb/def.c',
    'third_party/upb/upb/encode.c',
    'third_party/upb/upb/msg.c',
    'third_party/upb/upb/reflection.c',
    'third_party/upb/upb/table.c',
    'third_party/upb/upb/text_encode.c',
    'third_party/upb/upb/upb.c',
    'third_party/zlib/adler32.c',
    'third_party/zlib/compress.c',
    'third_party/zlib/crc32.c',
    'third_party/zlib/deflate.c',
    'third_party/zlib/gzclose.c',
    'third_party/zlib/gzlib.c',
    'third_party/zlib/gzread.c',
    'third_party/zlib/gzwrite.c',
    'third_party/zlib/infback.c',
    'third_party/zlib/inffast.c',
    'third_party/zlib/inflate.c',
    'third_party/zlib/inftrees.c',
    'third_party/zlib/trees.c',
    'third_party/zlib/uncompr.c',
    'third_party/zlib/zutil.c',
]

ASM_SOURCE_FILES = {
    'crypto_ios_aarch64': [
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/chacha/chacha-armv8.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/aesv8-armx64.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/armv8-mont.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/ghash-neon-armv8.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/ghashv8-armx64.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/sha1-armv8.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/sha256-armv8.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/sha512-armv8.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/fipsmodule/vpaes-armv8.S',
        'third_party/boringssl-with-bazel/ios-aarch64/crypto/test/trampoline-armv8.S',
    ],
    'crypto_ios_arm': [
        'third_party/boringssl-with-bazel/ios-arm/crypto/chacha/chacha-armv4.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/aesv8-armx32.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/armv4-mont.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/bsaes-armv7.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/ghash-armv4.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/ghashv8-armx32.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/sha1-armv4-large.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/sha256-armv4.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/sha512-armv4.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/fipsmodule/vpaes-armv7.S',
        'third_party/boringssl-with-bazel/ios-arm/crypto/test/trampoline-armv4.S',
    ],
    'crypto_linux_aarch64': [
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/chacha/chacha-armv8.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/aesv8-armx64.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/armv8-mont.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/ghash-neon-armv8.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/ghashv8-armx64.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/sha1-armv8.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/sha256-armv8.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/sha512-armv8.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/fipsmodule/vpaes-armv8.S',
        'third_party/boringssl-with-bazel/linux-aarch64/crypto/test/trampoline-armv8.S',
    ],
    'crypto_linux_arm': [
        'third_party/boringssl-with-bazel/linux-arm/crypto/chacha/chacha-armv4.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/aesv8-armx32.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/armv4-mont.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/bsaes-armv7.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/ghash-armv4.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/ghashv8-armx32.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/sha1-armv4-large.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/sha256-armv4.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/sha512-armv4.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/fipsmodule/vpaes-armv7.S',
        'third_party/boringssl-with-bazel/linux-arm/crypto/test/trampoline-armv4.S',
        'third_party/boringssl-with-bazel/src/crypto/curve25519/asm/x25519-asm-arm.S',
        'third_party/boringssl-with-bazel/src/crypto/poly1305/poly1305_arm_asm.S',
    ],
    'crypto_linux_ppc64le': [
        'third_party/boringssl-with-bazel/linux-ppc64le/crypto/fipsmodule/aesp8-ppc.S',
        'third_party/boringssl-with-bazel/linux-ppc64le/crypto/fipsmodule/ghashp8-ppc.S',
        'third_party/boringssl-with-bazel/linux-ppc64le/crypto/test/trampoline-ppc.S',
    ],
    'crypto_linux_x86': [
        'third_party/boringssl-with-bazel/linux-x86/crypto/chacha/chacha-x86.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/aesni-x86.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/bn-586.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/co-586.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/ghash-ssse3-x86.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/ghash-x86.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/md5-586.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/sha1-586.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/sha256-586.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/sha512-586.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/vpaes-x86.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/fipsmodule/x86-mont.S',
        'third_party/boringssl-with-bazel/linux-x86/crypto/test/trampoline-x86.S',
    ],
    'crypto_linux_x86_64': [
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/chacha/chacha-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/cipher_extra/aes128gcmsiv-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/cipher_extra/chacha20_poly1305_x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/aesni-gcm-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/aesni-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/ghash-ssse3-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/ghash-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/md5-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/p256-x86_64-asm.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/p256_beeu-x86_64-asm.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/rdrand-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/rsaz-avx2.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/sha1-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/sha256-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/sha512-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/vpaes-x86_64.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/x86_64-mont.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/fipsmodule/x86_64-mont5.S',
        'third_party/boringssl-with-bazel/linux-x86_64/crypto/test/trampoline-x86_64.S',
        'third_party/boringssl-with-bazel/src/crypto/hrss/asm/poly_rq_mul.S',
    ],
    'crypto_mac_x86': [
        'third_party/boringssl-with-bazel/mac-x86/crypto/chacha/chacha-x86.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/aesni-x86.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/bn-586.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/co-586.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/ghash-ssse3-x86.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/ghash-x86.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/md5-586.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/sha1-586.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/sha256-586.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/sha512-586.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/vpaes-x86.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/fipsmodule/x86-mont.S',
        'third_party/boringssl-with-bazel/mac-x86/crypto/test/trampoline-x86.S',
    ],
    'crypto_mac_x86_64': [
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/chacha/chacha-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/cipher_extra/aes128gcmsiv-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/cipher_extra/chacha20_poly1305_x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/aesni-gcm-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/aesni-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/ghash-ssse3-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/ghash-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/md5-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/p256-x86_64-asm.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/p256_beeu-x86_64-asm.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/rdrand-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/rsaz-avx2.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/sha1-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/sha256-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/sha512-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/vpaes-x86_64.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/x86_64-mont.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/fipsmodule/x86_64-mont5.S',
        'third_party/boringssl-with-bazel/mac-x86_64/crypto/test/trampoline-x86_64.S',
    ],
    'crypto_win_aarch64': [
        'third_party/boringssl-with-bazel/win-aarch64/crypto/chacha/chacha-armv8.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/aesv8-armx64.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/armv8-mont.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/ghash-neon-armv8.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/ghashv8-armx64.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/sha1-armv8.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/sha256-armv8.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/sha512-armv8.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/fipsmodule/vpaes-armv8.S',
        'third_party/boringssl-with-bazel/win-aarch64/crypto/test/trampoline-armv8.S',
    ],
    'crypto_win_x86': [
        'third_party/boringssl-with-bazel/win-x86/crypto/chacha/chacha-x86.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/aesni-x86.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/bn-586.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/co-586.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/ghash-ssse3-x86.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/ghash-x86.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/md5-586.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/sha1-586.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/sha256-586.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/sha512-586.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/vpaes-x86.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/fipsmodule/x86-mont.asm',
        'third_party/boringssl-with-bazel/win-x86/crypto/test/trampoline-x86.asm',
    ],
    'crypto_win_x86_64': [
        'third_party/boringssl-with-bazel/win-x86_64/crypto/chacha/chacha-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/cipher_extra/aes128gcmsiv-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/cipher_extra/chacha20_poly1305_x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/aesni-gcm-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/aesni-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/ghash-ssse3-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/ghash-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/md5-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/p256-x86_64-asm.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/p256_beeu-x86_64-asm.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/rdrand-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/rsaz-avx2.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/sha1-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/sha256-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/sha512-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/vpaes-x86_64.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/x86_64-mont.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/fipsmodule/x86_64-mont5.asm',
        'third_party/boringssl-with-bazel/win-x86_64/crypto/test/trampoline-x86_64.asm',
    ],
}



#!/usr/bin/env python3
# coding=utf-8
# Copyright (c) 2020, Google Inc.
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
# SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
# OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
# CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

"""This script translates JSON test vectors to BoringSSL's "FileTest" format.

Usage: translate_test_vectors.py TEST_VECTORS_JSON_FILE

The TEST_VECTORS_JSON_FILE is expected to come from the HPKE reference
implementation at https://github.com/cisco/go-hpke. The output file is
hardcoded as "hpke_test_vectors.txt".
"""

import collections
import json
import sys

HPKE_MODE_BASE = 0
HPKE_MODE_PSK = 1
HPKE_DHKEM_X25519_SHA256 = 0x0020
HPKE_HKDF_SHA256 = 0x0001
HPKE_AEAD_EXPORT_ONLY = 0xffff


def read_test_vectors_and_generate_code(json_file_in_path, test_file_out_path):
  """Translates JSON test vectors into BoringSSL's FileTest language.

    Args:
      json_file_in_path: Path to the JSON test vectors file.
      test_file_out_path: Path to output file.
  """

  # Load the JSON file into |test_vecs|.
  with open(json_file_in_path) as file_in:
    test_vecs = json.load(file_in)

  lines = []
  for test in test_vecs:
    # Filter out test cases that we don't use.
    if (test["mode"] != HPKE_MODE_BASE or
        test["kem_id"] != HPKE_DHKEM_X25519_SHA256 or
        test["aead_id"] == HPKE_AEAD_EXPORT_ONLY or
        test["kdf_id"] != HPKE_HKDF_SHA256):
      continue

    keys = ["mode", "kdf_id", "aead_id", "info", "skRm", "skEm", "pkRm", "pkEm"]

    if test["mode"] == HPKE_MODE_PSK:
      keys.append("psk")
      keys.append("psk_id")

    for key in keys:
      lines.append("{} = {}".format(key, str(test[key])))

    for i, enc in enumerate(test["encryptions"]):
      lines.append("# encryptions[{}]".format(i))
      for key in ("aad", "ciphertext", "plaintext"):
        lines.append("{} = {}".format(key, str(enc[key])))

    for i, exp in enumerate(test["exports"]):
      lines.append("# exports[{}]".format(i))
      for key in ("exporter_context", "L", "exported_value"):
        lines.append("{} = {}".format(key, str(exp[key])))

    lines.append("")

  with open(test_file_out_path, "w") as file_out:
    file_out.write("\n".join(lines))


def main(argv):
  if len(argv) != 2:
    print(__doc__)
    sys.exit(1)

  read_test_vectors_and_generate_code(argv[1], "hpke_test_vectors.txt")


if __name__ == "__main__":
  main(sys.argv)



# Copyright 2015 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A setup module for the GRPC Python package."""

# setuptools need to be imported before distutils. Otherwise it might lead to
# undesirable behaviors or errors.
import setuptools  # isort:skip

# Monkey Patch the unix compiler to accept ASM
# files used by boring SSL.
from distutils.unixccompiler import UnixCCompiler

UnixCCompiler.src_extensions.append('.S')
del UnixCCompiler

from distutils import cygwinccompiler
from distutils import extension as _extension
from distutils import util
import os
import os.path
import platform
import re
import shlex
import shutil
import subprocess
from subprocess import PIPE
import sys
import sysconfig

import _metadata
import pkg_resources
from setuptools.command import egg_info

# Redirect the manifest template from MANIFEST.in to PYTHON-MANIFEST.in.
egg_info.manifest_maker.template = 'PYTHON-MANIFEST.in'

PY3 = sys.version_info.major == 3
PYTHON_STEM = os.path.join('src', 'python', 'grpcio')
CORE_INCLUDE = (
    'include',
    '.',
)
ABSL_INCLUDE = (os.path.join('third_party', 'abseil-cpp'),)
ADDRESS_SORTING_INCLUDE = (os.path.join('third_party', 'address_sorting',
                                        'include'),)
CARES_INCLUDE = (
    os.path.join('third_party', 'cares'),
    os.path.join('third_party', 'cares', 'cares'),
)
if 'darwin' in sys.platform:
    CARES_INCLUDE += (os.path.join('third_party', 'cares', 'config_darwin'),)
if 'freebsd' in sys.platform:
    CARES_INCLUDE += (os.path.join('third_party', 'cares', 'config_freebsd'),)
if 'linux' in sys.platform:
    CARES_INCLUDE += (os.path.join('third_party', 'cares', 'config_linux'),)
if 'openbsd' in sys.platform:
    CARES_INCLUDE += (os.path.join('third_party', 'cares', 'config_openbsd'),)
RE2_INCLUDE = (os.path.join('third_party', 're2'),)
SSL_INCLUDE = (os.path.join('third_party', 'boringssl-with-bazel', 'src',
                            'include'),)
UPB_INCLUDE = (os.path.join('third_party', 'upb'),)
UPB_GRPC_GENERATED_INCLUDE = (os.path.join('src', 'core', 'ext',
                                           'upb-generated'),)
UPBDEFS_GRPC_GENERATED_INCLUDE = (os.path.join('src', 'core', 'ext',
                                               'upbdefs-generated'),)
XXHASH_INCLUDE = (os.path.join('third_party', 'xxhash'),)
ZLIB_INCLUDE = (os.path.join('third_party', 'zlib'),)
README = os.path.join(PYTHON_STEM, 'README.rst')

# Ensure we're in the proper directory whether or not we're being used by pip.
os.chdir(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, os.path.abspath(PYTHON_STEM))

# Break import-style to ensure we can actually find our in-repo dependencies.
import _parallel_compile_patch
import _spawn_patch
import grpc_core_dependencies

import commands
import grpc_version

_parallel_compile_patch.monkeypatch_compile_maybe()
_spawn_patch.monkeypatch_spawn()

LICENSE = 'Apache License 2.0'

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'License :: OSI Approved :: Apache Software License',
]


def _env_bool_value(env_name, default):
    """Parses a bool option from an environment variable"""
    return os.environ.get(env_name, default).upper() not in ['FALSE', '0', '']


BUILD_WITH_BORING_SSL_ASM = _env_bool_value('GRPC_BUILD_WITH_BORING_SSL_ASM',
                                            'True')

# Export this environment variable to override the platform variant that will
# be chosen for boringssl assembly optimizations. This option is useful when
# crosscompiling and the host platform as obtained by distutils.utils.get_platform()
# doesn't match the platform we are targetting.
# Example value: "linux-aarch64"
BUILD_OVERRIDE_BORING_SSL_ASM_PLATFORM = os.environ.get(
    'GRPC_BUILD_OVERRIDE_BORING_SSL_ASM_PLATFORM', '')

# Environment variable to determine whether or not the Cython extension should
# *use* Cython or use the generated C files. Note that this requires the C files
# to have been generated by building first *with* Cython support. Even if this
# is set to false, if the script detects that the generated `.c` file isn't
# present, then it will still attempt to use Cython.
BUILD_WITH_CYTHON = _env_bool_value('GRPC_PYTHON_BUILD_WITH_CYTHON', 'False')

# Export this variable to use the system installation of openssl. You need to
# have the header files installed (in /usr/include/openssl) and during
# runtime, the shared library must be installed
BUILD_WITH_SYSTEM_OPENSSL = _env_bool_value('GRPC_PYTHON_BUILD_SYSTEM_OPENSSL',
                                            'False')

# Export this variable to use the system installation of zlib. You need to
# have the header files installed (in /usr/include/) and during
# runtime, the shared library must be installed
BUILD_WITH_SYSTEM_ZLIB = _env_bool_value('GRPC_PYTHON_BUILD_SYSTEM_ZLIB',
                                         'False')

# Export this variable to use the system installation of cares. You need to
# have the header files installed (in /usr/include/) and during
# runtime, the shared library must be installed
BUILD_WITH_SYSTEM_CARES = _env_bool_value('GRPC_PYTHON_BUILD_SYSTEM_CARES',
                                          'False')

# Export this variable to use the system installation of re2. You need to
# have the header files installed (in /usr/include/re2) and during
# runtime, the shared library must be installed
BUILD_WITH_SYSTEM_RE2 = _env_bool_value('GRPC_PYTHON_BUILD_SYSTEM_RE2', 'False')

# Export this variable to force building the python extension with a statically linked libstdc++.
# At least on linux, this is normally not needed as we can build manylinux-compatible wheels on linux just fine
# without statically linking libstdc++ (which leads to a slight increase in the wheel size).
# This option is useful when crosscompiling wheels for aarch64 where
# it's difficult to ensure that the crosscompilation toolchain has a high-enough version
# of GCC (we require >4.9) but still uses old-enough libstdc++ symbols.
# TODO(jtattermusch): remove this workaround once issues with crosscompiler version are resolved.
BUILD_WITH_STATIC_LIBSTDCXX = _env_bool_value(
    'GRPC_PYTHON_BUILD_WITH_STATIC_LIBSTDCXX', 'False')

# For local development use only: This skips building gRPC Core and its
# dependencies, including protobuf and boringssl. This allows "incremental"
# compilation by first building gRPC Core using make, then building only the
# Python/Cython layers here.
#
# Note that this requires libboringssl.a in the libs/{dbg,opt}/ directory, which
# may require configuring make to not use the system openssl implementation:
#
#    make HAS_SYSTEM_OPENSSL_ALPN=0
#
# TODO(ericgribkoff) Respect the BUILD_WITH_SYSTEM_* flags alongside this option
USE_PREBUILT_GRPC_CORE = _env_bool_value('GRPC_PYTHON_USE_PREBUILT_GRPC_CORE',
                                         'False')

# If this environmental variable is set, GRPC will not try to be compatible with
# libc versions old than the one it was compiled against.
DISABLE_LIBC_COMPATIBILITY = _env_bool_value(
    'GRPC_PYTHON_DISABLE_LIBC_COMPATIBILITY', 'False')

# Environment variable to determine whether or not to enable coverage analysis
# in Cython modules.
ENABLE_CYTHON_TRACING = _env_bool_value('GRPC_PYTHON_ENABLE_CYTHON_TRACING',
                                        'False')

# Environment variable specifying whether or not there's interest in setting up
# documentation building.
ENABLE_DOCUMENTATION_BUILD = _env_bool_value(
    'GRPC_PYTHON_ENABLE_DOCUMENTATION_BUILD', 'False')


def check_linker_need_libatomic():
    """Test if linker on system needs libatomic."""
    code_test = (b'#include <atomic>\n' +
                 b'int main() { return std::atomic<int64_t>{}; }')
    cxx = os.environ.get('CXX', 'c++')
    cpp_test = subprocess.Popen([cxx, '-x', 'c++', '-std=c++11', '-'],
                                stdin=PIPE,
                                stdout=PIPE,
                                stderr=PIPE)
    cpp_test.communicate(input=code_test)
    if cpp_test.returncode == 0:
        return False
    # Double-check to see if -latomic actually can solve the problem.
    # https://github.com/grpc/grpc/issues/22491
    cpp_test = subprocess.Popen(
        [cxx, '-x', 'c++', '-std=c++11', '-latomic', '-'],
        stdin=PIPE,
        stdout=PIPE,
        stderr=PIPE)
    cpp_test.communicate(input=code_test)
    return cpp_test.returncode == 0


# There are some situations (like on Windows) where CC, CFLAGS, and LDFLAGS are
# entirely ignored/dropped/forgotten by distutils and its Cygwin/MinGW support.
# We use these environment variables to thus get around that without locking
# ourselves in w.r.t. the multitude of operating systems this ought to build on.
# We can also use these variables as a way to inject environment-specific
# compiler/linker flags. We assume GCC-like compilers and/or MinGW as a
# reasonable default.
EXTRA_ENV_COMPILE_ARGS = os.environ.get('GRPC_PYTHON_CFLAGS', None)
EXTRA_ENV_LINK_ARGS = os.environ.get('GRPC_PYTHON_LDFLAGS', None)
if EXTRA_ENV_COMPILE_ARGS is None:
    EXTRA_ENV_COMPILE_ARGS = ' -std=c++11'
    if 'win32' in sys.platform:
        if sys.version_info < (3, 5):
            EXTRA_ENV_COMPILE_ARGS += ' -D_hypot=hypot'
            # We use define flags here and don't directly add to DEFINE_MACROS below to
            # ensure that the expert user/builder has a way of turning it off (via the
            # envvars) without adding yet more GRPC-specific envvars.
            # See https://sourceforge.net/p/mingw-w64/bugs/363/
            if '32' in platform.architecture()[0]:
                EXTRA_ENV_COMPILE_ARGS += ' -D_ftime=_ftime32 -D_timeb=__timeb32 -D_ftime_s=_ftime32_s'
            else:
                EXTRA_ENV_COMPILE_ARGS += ' -D_ftime=_ftime64 -D_timeb=__timeb64'
        else:
            # We need to statically link the C++ Runtime, only the C runtime is
            # available dynamically
            EXTRA_ENV_COMPILE_ARGS += ' /MT'
    elif "linux" in sys.platform:
        EXTRA_ENV_COMPILE_ARGS += ' -std=gnu99 -fvisibility=hidden -fno-wrapv -fno-exceptions'
    elif "darwin" in sys.platform:
        EXTRA_ENV_COMPILE_ARGS += ' -stdlib=libc++ -fvisibility=hidden -fno-wrapv -fno-exceptions -DHAVE_UNISTD_H'

if EXTRA_ENV_LINK_ARGS is None:
    EXTRA_ENV_LINK_ARGS = ''
    if "linux" in sys.platform or "darwin" in sys.platform:
        EXTRA_ENV_LINK_ARGS += ' -lpthread'
        if check_linker_need_libatomic():
            EXTRA_ENV_LINK_ARGS += ' -latomic'
    elif "win32" in sys.platform and sys.version_info < (3, 5):
        msvcr = cygwinccompiler.get_msvcr()[0]
        EXTRA_ENV_LINK_ARGS += (
            ' -static-libgcc -static-libstdc++ -mcrtdll={msvcr}'
            ' -static -lshlwapi'.format(msvcr=msvcr))
    if "linux" in sys.platform:
        EXTRA_ENV_LINK_ARGS += ' -Wl,-wrap,memcpy -static-libgcc'

EXTRA_COMPILE_ARGS = shlex.split(EXTRA_ENV_COMPILE_ARGS)
EXTRA_LINK_ARGS = shlex.split(EXTRA_ENV_LINK_ARGS)

if BUILD_WITH_STATIC_LIBSTDCXX:
    EXTRA_LINK_ARGS.append('-static-libstdc++')

CYTHON_EXTENSION_PACKAGE_NAMES = ()

CYTHON_EXTENSION_MODULE_NAMES = ('grpc._cython.cygrpc',)

CYTHON_HELPER_C_FILES = ()

CORE_C_FILES = tuple(grpc_core_dependencies.CORE_SOURCE_FILES)
if "win32" in sys.platform:
    CORE_C_FILES = filter(lambda x: 'third_party/cares' not in x, CORE_C_FILES)

if BUILD_WITH_SYSTEM_OPENSSL:
    CORE_C_FILES = filter(lambda x: 'third_party/boringssl' not in x,
                          CORE_C_FILES)
    CORE_C_FILES = filter(lambda x: 'src/boringssl' not in x, CORE_C_FILES)
    SSL_INCLUDE = (os.path.join('/usr', 'include', 'openssl'),)

if BUILD_WITH_SYSTEM_ZLIB:
    CORE_C_FILES = filter(lambda x: 'third_party/zlib' not in x, CORE_C_FILES)
    ZLIB_INCLUDE = (os.path.join('/usr', 'include'),)

if BUILD_WITH_SYSTEM_CARES:
    CORE_C_FILES = filter(lambda x: 'third_party/cares' not in x, CORE_C_FILES)
    CARES_INCLUDE = (os.path.join('/usr', 'include'),)

if BUILD_WITH_SYSTEM_RE2:
    CORE_C_FILES = filter(lambda x: 'third_party/re2' not in x, CORE_C_FILES)
    RE2_INCLUDE = (os.path.join('/usr', 'include', 're2'),)

EXTENSION_INCLUDE_DIRECTORIES = ((PYTHON_STEM,) + CORE_INCLUDE + ABSL_INCLUDE +
                                 ADDRESS_SORTING_INCLUDE + CARES_INCLUDE +
                                 RE2_INCLUDE + SSL_INCLUDE + UPB_INCLUDE +
                                 UPB_GRPC_GENERATED_INCLUDE +
                                 UPBDEFS_GRPC_GENERATED_INCLUDE +
                                 XXHASH_INCLUDE + ZLIB_INCLUDE)

EXTENSION_LIBRARIES = ()
if "linux" in sys.platform:
    EXTENSION_LIBRARIES += ('rt',)
if not "win32" in sys.platform:
    EXTENSION_LIBRARIES += ('m',)
if "win32" in sys.platform:
    EXTENSION_LIBRARIES += (
        'advapi32',
        'ws2_32',
        'dbghelp',
    )
if BUILD_WITH_SYSTEM_OPENSSL:
    EXTENSION_LIBRARIES += (
        'ssl',
        'crypto',
    )
if BUILD_WITH_SYSTEM_ZLIB:
    EXTENSION_LIBRARIES += ('z',)
if BUILD_WITH_SYSTEM_CARES:
    EXTENSION_LIBRARIES += ('cares',)
if BUILD_WITH_SYSTEM_RE2:
    EXTENSION_LIBRARIES += ('re2',)

DEFINE_MACROS = (('_WIN32_WINNT', 0x600),)
asm_files = []


# Quotes on Windows build macros are evaluated differently from other platforms,
# so we must apply quotes asymmetrically in order to yield the proper result in
# the binary.
def _quote_build_define(argument):
    if "win32" in sys.platform:
        return '"\\\"{}\\\""'.format(argument)
    return '"{}"'.format(argument)


DEFINE_MACROS += (
    ("GRPC_XDS_USER_AGENT_NAME_SUFFIX", _quote_build_define("Python")),
    ("GRPC_XDS_USER_AGENT_VERSION_SUFFIX",
     _quote_build_define(_metadata.__version__)),
)

asm_key = ''
if BUILD_WITH_BORING_SSL_ASM and not BUILD_WITH_SYSTEM_OPENSSL:
    boringssl_asm_platform = BUILD_OVERRIDE_BORING_SSL_ASM_PLATFORM if BUILD_OVERRIDE_BORING_SSL_ASM_PLATFORM else util.get_platform(
    )
    LINUX_X86_64 = 'linux-x86_64'
    LINUX_ARM = 'linux-arm'
    LINUX_AARCH64 = 'linux-aarch64'
    if LINUX_X86_64 == boringssl_asm_platform:
        asm_key = 'crypto_linux_x86_64'
    elif LINUX_ARM == boringssl_asm_platform:
        asm_key = 'crypto_linux_arm'
    elif LINUX_AARCH64 == boringssl_asm_platform:
        asm_key = 'crypto_linux_aarch64'
    elif "mac" in boringssl_asm_platform and "x86_64" in boringssl_asm_platform:
        asm_key = 'crypto_mac_x86_64'
    else:
        print("ASM Builds for BoringSSL currently not supported on:",
              boringssl_asm_platform)
if asm_key:
    asm_files = grpc_core_dependencies.ASM_SOURCE_FILES[asm_key]
else:
    DEFINE_MACROS += (('OPENSSL_NO_ASM', 1),)

if not DISABLE_LIBC_COMPATIBILITY:
    DEFINE_MACROS += (('GPR_BACKWARDS_COMPATIBILITY_MODE', 1),)

if "win32" in sys.platform:
    # TODO(zyc): Re-enable c-ares on x64 and x86 windows after fixing the
    # ares_library_init compilation issue
    DEFINE_MACROS += (
        ('WIN32_LEAN_AND_MEAN', 1),
        ('CARES_STATICLIB', 1),
        ('GRPC_ARES', 0),
        ('NTDDI_VERSION', 0x06000000),
        ('NOMINMAX', 1),
    )
    if '64bit' in platform.architecture()[0]:
        DEFINE_MACROS += (('MS_WIN64', 1),)
    elif sys.version_info >= (3, 5):
        # For some reason, this is needed to get access to inet_pton/inet_ntop
        # on msvc, but only for 32 bits
        DEFINE_MACROS += (('NTDDI_VERSION', 0x06000000),)
else:
    DEFINE_MACROS += (
        ('HAVE_CONFIG_H', 1),
        ('GRPC_ENABLE_FORK_SUPPORT', 1),
    )

LDFLAGS = tuple(EXTRA_LINK_ARGS)
CFLAGS = tuple(EXTRA_COMPILE_ARGS)
if "linux" in sys.platform or "darwin" in sys.platform:
    pymodinit_type = 'PyObject*' if PY3 else 'void'
    pymodinit = 'extern "C" __attribute__((visibility ("default"))) {}'.format(
        pymodinit_type)
    DEFINE_MACROS += (('PyMODINIT_FUNC', pymodinit),)
    DEFINE_MACROS += (('GRPC_POSIX_FORK_ALLOW_PTHREAD_ATFORK', 1),)

# By default, Python3 distutils enforces compatibility of
# c plugins (.so files) with the OSX version Python was built with.
# We need OSX 10.10, the oldest which supports C++ thread_local.
# Python 3.9: Mac OS Big Sur sysconfig.get_config_var('MACOSX_DEPLOYMENT_TARGET') returns int (11)
if 'darwin' in sys.platform:
    mac_target = sysconfig.get_config_var('MACOSX_DEPLOYMENT_TARGET')
    if mac_target:
        mac_target = pkg_resources.parse_version(str(mac_target))
        if mac_target < pkg_resources.parse_version('10.10.0'):
            os.environ['MACOSX_DEPLOYMENT_TARGET'] = '10.10'
            os.environ['_PYTHON_HOST_PLATFORM'] = re.sub(
                r'macosx-[0-9]+\.[0-9]+-(.+)', r'macosx-10.10-\1',
                util.get_platform())


def cython_extensions_and_necessity():
    cython_module_files = [
        os.path.join(PYTHON_STEM,
                     name.replace('.', '/') + '.pyx')
        for name in CYTHON_EXTENSION_MODULE_NAMES
    ]
    config = os.environ.get('CONFIG', 'opt')
    prefix = 'libs/' + config + '/'
    if USE_PREBUILT_GRPC_CORE:
        extra_objects = [
            prefix + 'libares.a', prefix + 'libboringssl.a',
            prefix + 'libgpr.a', prefix + 'libgrpc.a'
        ]
        core_c_files = []
    else:
        core_c_files = list(CORE_C_FILES)
        extra_objects = []
    extensions = [
        _extension.Extension(
            name=module_name,
            sources=([module_file] + list(CYTHON_HELPER_C_FILES) +
                     core_c_files + asm_files),
            include_dirs=list(EXTENSION_INCLUDE_DIRECTORIES),
            libraries=list(EXTENSION_LIBRARIES),
            define_macros=list(DEFINE_MACROS),
            extra_objects=extra_objects,
            extra_compile_args=list(CFLAGS),
            extra_link_args=list(LDFLAGS),
        ) for (module_name, module_file
              ) in zip(list(CYTHON_EXTENSION_MODULE_NAMES), cython_module_files)
    ]
    need_cython = BUILD_WITH_CYTHON
    if not BUILD_WITH_CYTHON:
        need_cython = need_cython or not commands.check_and_update_cythonization(
            extensions)
    # TODO: the strategy for conditional compiling and exposing the aio Cython
    # dependencies will be revisited by https://github.com/grpc/grpc/issues/19728
    return commands.try_cythonize(extensions,
                                  linetracing=ENABLE_CYTHON_TRACING,
                                  mandatory=BUILD_WITH_CYTHON), need_cython


CYTHON_EXTENSION_MODULES, need_cython = cython_extensions_and_necessity()

PACKAGE_DIRECTORIES = {
    '': PYTHON_STEM,
}

INSTALL_REQUIRES = (
    "six>=1.5.2",
    "futures>=2.2.0; python_version<'3.2'",
    "enum34>=1.0.4; python_version<'3.4'",
)
EXTRAS_REQUIRES = {
    'protobuf': 'grpcio-tools>={version}'.format(version=grpc_version.VERSION),
}

SETUP_REQUIRES = INSTALL_REQUIRES + (
    'Sphinx~=1.8.1',
    'six>=1.10',
) if ENABLE_DOCUMENTATION_BUILD else ()

try:
    import Cython
except ImportError:
    if BUILD_WITH_CYTHON:
        sys.stderr.write(
            "You requested a Cython build via GRPC_PYTHON_BUILD_WITH_CYTHON, "
            "but do not have Cython installed. We won't stop you from using "
            "other commands, but the extension files will fail to build.\n")
    elif need_cython:
        sys.stderr.write(
            'We could not find Cython. Setup may take 10-20 minutes.\n')
        SETUP_REQUIRES += ('cython>=0.23',)

COMMAND_CLASS = {
    'doc': commands.SphinxDocumentation,
    'build_project_metadata': commands.BuildProjectMetadata,
    'build_py': commands.BuildPy,
    'build_ext': commands.BuildExt,
    'gather': commands.Gather,
    'clean': commands.Clean,
}

# Ensure that package data is copied over before any commands have been run:
credentials_dir = os.path.join(PYTHON_STEM, 'grpc', '_cython', '_credentials')
try:
    os.mkdir(credentials_dir)
except OSError:
    pass
shutil.copyfile(os.path.join('etc', 'roots.pem'),
                os.path.join(credentials_dir, 'roots.pem'))

PACKAGE_DATA = {
    # Binaries that may or may not be present in the final installation, but are
    # mentioned here for completeness.
    'grpc._cython': [
        '_credentials/roots.pem',
        '_windows/grpc_c.32.python',
        '_windows/grpc_c.64.python',
    ],
}
PACKAGES = setuptools.find_packages(PYTHON_STEM)

setuptools.setup(
    name='grpcio',
    version=grpc_version.VERSION,
    description='HTTP/2-based RPC framework',
    author='The gRPC Authors',
    author_email='grpc-io@googlegroups.com',
    url='https://grpc.io',
    license=LICENSE,
    classifiers=CLASSIFIERS,
    long_description=open(README).read(),
    ext_modules=CYTHON_EXTENSION_MODULES,
    packages=list(PACKAGES),
    package_dir=PACKAGE_DIRECTORIES,
    package_data=PACKAGE_DATA,
    install_requires=INSTALL_REQUIRES,
    extras_require=EXTRAS_REQUIRES,
    setup_requires=SETUP_REQUIRES,
    cmdclass=COMMAND_CLASS,
)



# Copyright 2017 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import collections


class InitialMetadataFlags:
  used_mask = GRPC_INITIAL_METADATA_USED_MASK
  wait_for_ready = GRPC_INITIAL_METADATA_WAIT_FOR_READY
  wait_for_ready_explicitly_set = GRPC_INITIAL_METADATA_WAIT_FOR_READY_EXPLICITLY_SET


_Metadatum = collections.namedtuple('_Metadatum', ('key', 'value',))


cdef void _store_c_metadata(
    metadata, grpc_metadata **c_metadata, size_t *c_count) except *:
  if metadata is None:
    c_count[0] = 0
    c_metadata[0] = NULL
  else:
    metadatum_count = len(metadata)
    if metadatum_count == 0:
      c_count[0] = 0
      c_metadata[0] = NULL
    else:
      c_count[0] = metadatum_count
      c_metadata[0] = <grpc_metadata *>gpr_malloc(
          metadatum_count * sizeof(grpc_metadata))
      for index, (key, value) in enumerate(metadata):
        encoded_key = _encode(key)
        encoded_value = value if encoded_key[-4:] == b'-bin' else _encode(value)
        if not isinstance(encoded_value, bytes):
          raise TypeError('Binary metadata key="%s" expected bytes, got %s' % (
            key,
            type(encoded_value)
          ))
        c_metadata[0][index].key = _slice_from_bytes(encoded_key)
        c_metadata[0][index].value = _slice_from_bytes(encoded_value)


cdef void _release_c_metadata(grpc_metadata *c_metadata, int count) except *:
  if 0 < count:
    for index in range(count):
      grpc_slice_unref(c_metadata[index].key)
      grpc_slice_unref(c_metadata[index].value)
    gpr_free(c_metadata)


cdef tuple _metadatum(grpc_slice key_slice, grpc_slice value_slice):
  cdef bytes key = _slice_bytes(key_slice)
  cdef bytes value = _slice_bytes(value_slice)
  return <tuple>_Metadatum(
      _decode(key), value if key[-4:] == b'-bin' else _decode(value))


cdef tuple _metadata(grpc_metadata_array *c_metadata_array):
  return tuple(
      _metadatum(
          c_metadata_array.metadata[index].key,
          c_metadata_array.metadata[index].value)
      for index in range(c_metadata_array.count))



# Copyright 2019 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# distutils: language=c++

from libc cimport string
from libc.stdlib cimport malloc
from libcpp.string cimport string as cppstring

cdef grpc_error_handle grpc_error_none():
  return <grpc_error_handle>0

cdef grpc_error_handle socket_error(str syscall, str err):
  error_str = "{} failed: {}".format(syscall, err)
  error_bytes = str_to_bytes(error_str)
  return grpc_socket_error(error_bytes)

cdef resolved_addr_to_tuple(grpc_resolved_address* address):
  cdef cppstring res_str
  port = grpc_sockaddr_get_port(address)
  res_str = grpc_sockaddr_to_string(address, False)
  byte_str = _decode(res_str)
  if byte_str.endswith(':' + str(port)):
    byte_str = byte_str[:(0 - len(str(port)) - 1)]
  byte_str = byte_str.lstrip('[')
  byte_str = byte_str.rstrip(']')
  byte_str = '{}'.format(byte_str)
  return byte_str, port

cdef sockaddr_to_tuple(const grpc_sockaddr* address, size_t length):
  cdef grpc_resolved_address c_addr
  string.memcpy(<void*>c_addr.addr, <void*> address, length)
  c_addr.len = length
  return resolved_addr_to_tuple(&c_addr)

cdef sockaddr_is_ipv4(const grpc_sockaddr* address, size_t length):
  cdef grpc_resolved_address c_addr
  string.memcpy(<void*>c_addr.addr, <void*> address, length)
  c_addr.len = length
  return grpc_sockaddr_get_uri_scheme(&c_addr) == b'ipv4'

cdef grpc_resolved_addresses* tuples_to_resolvaddr(tups):
  cdef grpc_resolved_addresses* addresses
  tups_set = set((tup[4][0], tup[4][1]) for tup in tups)
  addresses = <grpc_resolved_addresses*> malloc(sizeof(grpc_resolved_addresses))
  addresses.naddrs = len(tups_set)
  addresses.addrs = <grpc_resolved_address*> malloc(sizeof(grpc_resolved_address) * len(tups_set))
  i = 0
  for tup in set(tups_set):
    hostname = str_to_bytes(tup[0])
    grpc_string_to_sockaddr(&addresses.addrs[i], hostname, tup[1])
    i += 1
  return addresses



# Copyright 2015 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Internal utilities for gRPC Python."""

import collections
import logging
import threading
import time

import grpc
from grpc import _common
import six

_LOGGER = logging.getLogger(__name__)

_DONE_CALLBACK_EXCEPTION_LOG_MESSAGE = (
    'Exception calling connectivity future "done" callback!')


class RpcMethodHandler(
        collections.namedtuple('_RpcMethodHandler', (
            'request_streaming',
            'response_streaming',
            'request_deserializer',
            'response_serializer',
            'unary_unary',
            'unary_stream',
            'stream_unary',
            'stream_stream',
        )), grpc.RpcMethodHandler):
    pass


class DictionaryGenericHandler(grpc.ServiceRpcHandler):

    def __init__(self, service, method_handlers):
        self._name = service
        self._method_handlers = {
            _common.fully_qualified_method(service, method): method_handler
            for method, method_handler in six.iteritems(method_handlers)
        }

    def service_name(self):
        return self._name

    def service(self, handler_call_details):
        return self._method_handlers.get(handler_call_details.method)


class _ChannelReadyFuture(grpc.Future):

    def __init__(self, channel):
        self._condition = threading.Condition()
        self._channel = channel

        self._matured = False
        self._cancelled = False
        self._done_callbacks = []

    def _block(self, timeout):
        until = None if timeout is None else time.time() + timeout
        with self._condition:
            while True:
                if self._cancelled:
                    raise grpc.FutureCancelledError()
                elif self._matured:
                    return
                else:
                    if until is None:
                        self._condition.wait()
                    else:
                        remaining = until - time.time()
                        if remaining < 0:
                            raise grpc.FutureTimeoutError()
                        else:
                            self._condition.wait(timeout=remaining)

    def _update(self, connectivity):
        with self._condition:
            if (not self._cancelled and
                    connectivity is grpc.ChannelConnectivity.READY):
                self._matured = True
                self._channel.unsubscribe(self._update)
                self._condition.notify_all()
                done_callbacks = tuple(self._done_callbacks)
                self._done_callbacks = None
            else:
                return

        for done_callback in done_callbacks:
            try:
                done_callback(self)
            except Exception:  # pylint: disable=broad-except
                _LOGGER.exception(_DONE_CALLBACK_EXCEPTION_LOG_MESSAGE)

    def cancel(self):
        with self._condition:
            if not self._matured:
                self._cancelled = True
                self._channel.unsubscribe(self._update)
                self._condition.notify_all()
                done_callbacks = tuple(self._done_callbacks)
                self._done_callbacks = None
            else:
                return False

        for done_callback in done_callbacks:
            try:
                done_callback(self)
            except Exception:  # pylint: disable=broad-except
                _LOGGER.exception(_DONE_CALLBACK_EXCEPTION_LOG_MESSAGE)

        return True

    def cancelled(self):
        with self._condition:
            return self._cancelled

    def running(self):
        with self._condition:
            return not self._cancelled and not self._matured

    def done(self):
        with self._condition:
            return self._cancelled or self._matured

    def result(self, timeout=None):
        self._block(timeout)

    def exception(self, timeout=None):
        self._block(timeout)

    def traceback(self, timeout=None):
        self._block(timeout)

    def add_done_callback(self, fn):
        with self._condition:
            if not self._cancelled and not self._matured:
                self._done_callbacks.append(fn)
                return

        fn(self)

    def start(self):
        with self._condition:
            self._channel.subscribe(self._update, try_to_connect=True)

    def __del__(self):
        with self._condition:
            if not self._cancelled and not self._matured:
                self._channel.unsubscribe(self._update)


def channel_ready_future(channel):
    ready_future = _ChannelReadyFuture(channel)
    ready_future.start()
    return ready_future



#!/usr/bin/env python2.7
# Copyright 2015 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
import os
import sys
import yaml

run_dir = os.path.dirname(sys.argv[0])
sources_path = os.path.abspath(
    os.path.join(run_dir,
                 '../../third_party/boringssl-with-bazel/sources.json'))
try:
    with open(sources_path, 'r') as s:
        sources = json.load(s)
except IOError:
    sources_path = os.path.abspath(
        os.path.join(run_dir,
                     '../../../../third_party/openssl/boringssl/sources.json'))
    with open(sources_path, 'r') as s:
        sources = json.load(s)


def map_dir(filename):
    return 'third_party/boringssl-with-bazel/' + filename


class Grpc(object):
    """Adapter for boring-SSL json sources files. """

    def __init__(self, sources):
        self.yaml = None
        self.WriteFiles(sources)

    def WriteFiles(self, files):
        test_binaries = ['ssl_test', 'crypto_test']
        asm_outputs = {
            key: value for key, value in files.items() if any(
                f.endswith(".S") or f.endswith(".asm") for f in value)
        }
        self.yaml = {
            '#':
                'generated with src/boringssl/gen_build_yaml.py',
            'raw_boringssl_build_output_for_debugging': {
                'files': files,
            },
            'libs': [
                {
                    'name':
                        'boringssl',
                    'build':
                        'private',
                    'language':
                        'c',
                    'secure':
                        False,
                    'src':
                        sorted(
                            map_dir(f) for f in files['ssl'] + files['crypto']),
                    'asm_src': {
                        k: [map_dir(f) for f in value
                           ] for k, value in asm_outputs.items()
                    },
                    'headers':
                        sorted(
                            map_dir(f)
                            # We want to include files['fips_fragments'], but not build them as objects.
                            # See https://boringssl-review.googlesource.com/c/boringssl/+/16946
                            for f in files['ssl_headers'] +
                            files['ssl_internal_headers'] +
                            files['crypto_headers'] +
                            files['crypto_internal_headers'] +
                            files['fips_fragments']),
                    'boringssl':
                        True,
                    'defaults':
                        'boringssl',
                },
                {
                    'name': 'boringssl_test_util',
                    'build': 'private',
                    'language': 'c++',
                    'secure': False,
                    'boringssl': True,
                    'defaults': 'boringssl',
                    'src': [map_dir(f) for f in sorted(files['test_support'])],
                }
            ],
            'targets': [{
                'name': 'boringssl_%s' % test,
                'build': 'test',
                'run': False,
                'secure': False,
                'language': 'c++',
                'src': sorted(map_dir(f) for f in files[test]),
                'vs_proj_dir': 'test/boringssl',
                'boringssl': True,
                'defaults': 'boringssl',
                'deps': [
                    'boringssl_test_util',
                    'boringssl',
                ]
            } for test in test_binaries],
            'tests': [{
                'name': 'boringssl_%s' % test,
                'args': [],
                'exclude_configs': ['asan', 'ubsan'],
                'ci_platforms': ['linux', 'mac', 'posix', 'windows'],
                'platforms': ['linux', 'mac', 'posix', 'windows'],
                'flaky': False,
                'gtest': True,
                'language': 'c++',
                'boringssl': True,
                'defaults': 'boringssl',
                'cpu_cost': 1.0
            } for test in test_binaries]
        }


grpc_platform = Grpc(sources)
print(yaml.dump(grpc_platform.yaml))
